DROP TABLE IF EXISTS VALORES_SENSORES;
DROP TABLE IF EXISTS VALORES_STATUS;
DROP TABLE IF EXISTS VALORES_PARAMETROS;
DROP TABLE IF EXISTS MOTAS;
DROP TABLE IF EXISTS STATUS;
DROP TABLE IF EXISTS PARAMETROS;
DROP TABLE IF EXISTS TIPOS_PARAMETRO;
DROP TABLE IF EXISTS SENSORES;
DROP TABLE IF EXISTS USUARIOS;
DROP TABLE IF EXISTS MAPA;

CREATE TABLE MAPA (
	X INTEGER,
	Y INTEGER
);

CREATE TABLE USUARIOS (
	usuario TEXT,
    password TEXT,
	PRIMARY KEY (usuario)
);

CREATE TABLE SENSORES (
	id INTEGER PRIMARY KEY,
    descripcion TEXT,
    unidades TEXT,
    conversion TEXT
);

CREATE TABLE TIPOS_PARAMETRO (
	id INTEGER PRIMARY KEY,
    descripcion TEXT,
	longitud INTEGER
);

CREATE TABLE PARAMETROS (
	id INTEGER PRIMARY KEY,
    descripcion TEXT,
	id_tipos_parametro INTEGER,
	mota SMALLINT,
	interfaz TEXT,
    defecto TEXT
);

CREATE TABLE STATUS (
	id INTEGER PRIMARY KEY,
    descripcion TEXT,
	valor_critico NUMERIC,
	comparacion TEXT,
	alerta TEXT,
    unidades TEXT,
    conversion TEXT
);

CREATE TABLE MOTAS (
	id INTEGER PRIMARY KEY,
    ip TEXT,
	fecha DATETIME,
    fechaUltimo DATETIME,
	sinc INTEGER,
	sincMota INTEGER
);

CREATE TABLE VALORES_SENSORES (
	id_mota INTEGER,
    id_sensor INTEGER,
	fecha DATETIME,
	valor NUMERIC,
	ultimo SMALLINT,
	PRIMARY KEY (id_mota, id_sensor, fecha)
);

CREATE TABLE VALORES_STATUS (
	id_mota INTEGER,
    id_status INTEGER,
	fecha DATETIME,
	valor NUMERIC,
	alerta TEXT,
	PRIMARY KEY (id_mota, id_status)
);

CREATE TABLE VALORES_PARAMETROS (
	id_mota INTEGER,
    id_parametro INTEGER,
	fecha DATETIME,
	valor TEXT,
	PRIMARY KEY (id_mota, id_parametro)
);

BEGIN TRANSACTION;

INSERT INTO SENSORES (id, descripcion, unidades, conversion) values (1, 'Temperatura (SHT21)','ºC','-46.85 + 175.72 * VAL / 65536');
INSERT INTO SENSORES (id, descripcion, unidades, conversion) values (2, 'Humedad (SHT21)','%HR','-6.0 + 125.0 * VAL / 65536');
INSERT INTO SENSORES (id, descripcion, unidades, conversion) values (3, 'Luz (MAX44009)','Lux','0.045 * (2 ^ (15 if VAL / 256 == 16 else VAL / 256)) * (VAL % 256)');
INSERT INTO SENSORES (id, descripcion, unidades, conversion) values (4, 'Aceleración X (ADXL346)','-','VAL');
INSERT INTO SENSORES (id, descripcion, unidades, conversion) values (5, 'Aceleración Y (ADXL346)','-','VAL');
INSERT INTO SENSORES (id, descripcion, unidades, conversion) values (6, 'Aceleración Z (ADXL346)','-','VAL');


INSERT INTO TIPOS_PARAMETRO (id, descripcion, longitud) values (1, 'Numérico', 4);
INSERT INTO TIPOS_PARAMETRO (id, descripcion, longitud) values (2, 'Texto', 255);
INSERT INTO TIPOS_PARAMETRO (id, descripcion, longitud) values (3, 'Lista IPv6 separadas por ,', 255);
INSERT INTO TIPOS_PARAMETRO (id, descripcion, longitud) values (4, 'Lista <ID> separadas por , (T)odos o (N)ninguno', 50);

INSERT INTO PARAMETROS (id, descripcion, id_tipos_parametro, mota, interfaz, defecto) values (1, 'Servidores', 3, 1, NULL, '[BBBB::1]:5683');
INSERT INTO PARAMETROS (id, descripcion, id_tipos_parametro, mota, interfaz, defecto) values (2, 'Tiempo entre muestras (segundos)', 1, 1, NULL, 300);
INSERT INTO PARAMETROS (id, descripcion, id_tipos_parametro, mota, interfaz, defecto) values (3, 'Lista de sensores activos', 4, 1, NULL, 'T');
INSERT INTO PARAMETROS (id, descripcion, id_tipos_parametro, mota, interfaz, defecto) values (4, 'Info. libre', 2, 0, 'nota', '-');
INSERT INTO PARAMETROS (id, descripcion, id_tipos_parametro, mota, interfaz, defecto) values (5, 'Coordenada X', 1, 0, 'X', 0);
INSERT INTO PARAMETROS (id, descripcion, id_tipos_parametro, mota, interfaz, defecto) values (6, 'Coordenada Y', 1, 0, 'Y', 0);
INSERT INTO PARAMETROS (id, descripcion, id_tipos_parametro, mota, interfaz, defecto) values (7, 'Descripción', 2, 0, 'desc', NULL);

INSERT INTO STATUS (id, descripcion, valor_critico, comparacion, alerta, unidades, conversion) values (1, 'Temperatura CPU', 100, '>=', 'Temperatura CPU demasiado alta', 'ºC', '((0.58134 * VAL)  -  (827 - (25 * 0.58134 * 4.2))) / (0.58134 * 4.2)');
INSERT INTO STATUS (id, descripcion, valor_critico, comparacion, alerta, unidades, conversion) values (2, 'Estado batería', 2.2, '<=', 'Batería baja', 'V', '(VAL * 3 * 1.19) / 2047');

INSERT INTO USUARIOS (usuario, password)  values ('administrador', 'b109f3bbbc244eb82441917ed06d618b9008dd09b3befd1b5e07394c706a8bb980b1d7785e5976ec049b46df5f1326af5a2ea6d103fd07c95385ffab0cacbc86');

INSERT INTO MAPA(X,Y) VALUES(1024, 768);

COMMIT; 
