'use strict';

var app = angular.module('WSNWebInterface');

app.run(function( wsnWebInterfaceDataFactory, wsnWebInterfaceLoginFactory, $uibModal) {
	wsnWebInterfaceLoginFactory.getLogin().then(
		function(res) {
			if (res.data.usuario) {
				wsnWebInterfaceDataFactory.setUsuarioLogado(res.data.usuario);
			}
		},
		function(error) {
			console.log(error);
		}	
	);
});

app.controller('LoginCabeceraController', ['$scope', 'wsnWebInterfaceDataFactory', function($scope, wsnWebInterfaceDataFactory) {
	$scope.cabecera = 'Login';
    $scope.icono = 'glyphicon glyphicon-log-in';
    $scope.$watch(
      function() { return wsnWebInterfaceDataFactory.getUsuarioLogado(); },
      function(newVal, oldVal) {
          if (newVal) {
              $scope.cabecera = newVal;
              $scope.icono = 'glyphicon glyphicon-log-out';
          }else {
              $scope.cabecera = 'Login';
              $scope.icono = 'glyphicon glyphicon-log-in';
          }
       }  
    );
}]);

app.controller('LoginController', ['$scope', '$uibModal', 'wsnWebInterfaceLoginFactory', 'wsnWebInterfaceDataFactory', function($scope, $uibModal, wsnWebInterfaceLoginFactory, wsnWebInterfaceDataFactory) {
	mensajes($scope);
	$scope.logado = wsnWebInterfaceDataFactory.getUsuarioLogado() ? true : false;
	$scope.mensaje_cabecera = wsnWebInterfaceDataFactory.getUsuarioLogado() ? 'Ya esta logado como ' + wsnWebInterfaceDataFactory.getUsuarioLogado() : 'Página de login';

    $scope.login = function() {
        var loading = cargando($uibModal);
        limpiarMensajes($scope);
		loading.opened.then(function() {
			wsnWebInterfaceLoginFactory.login($scope.usuario, $scope.password).then(
				function(req) {
					setMensaje($scope, "Usuario logado");
					$scope.mensaje_cabecera = 'Ya esta logado como ' + $scope.usuario;
					wsnWebInterfaceDataFactory.setUsuarioLogado($scope.usuario);
					$scope.logado = true;
					loading.close();
				},
				function(error) {
					loading.close();
					console.log(error);
					setMensajeError($scope, error);
				}
			);
		});
    };
    
    $scope.logout = function() {
        var loading = cargando($uibModal);
        limpiarMensajes($scope);
		loading.opened.then(function() {
			wsnWebInterfaceLoginFactory.logout().then(
				function(req) {
					setMensaje($scope, "Se ha desconectado de la aplicación");
					$scope.mensaje_cabecera = 'Página de login';
					wsnWebInterfaceDataFactory.setUsuarioLogado(null);
					$scope.logado = false;
					loading.close();
				},
				function(error) {
					loading.close();
					console.log(error);
					setMensajeError($scope, error);
				}
			);
		});
    };  
}]);

app.controller('ModalControler', function ($scope, $uibModalInstance, datos, $filter) {
    $scope.datos = datos;
    $scope.titulo = datos.titulo || 'Ventana de información';
    $scope.buscador = '';
    function init() {
        if ($scope.datos.paginacion)
             preparaPaginacion($scope.datos.paginacion, $filter, $scope.datos.motas, $scope.buscador);
    };
    init();
    
    // Funcion de ordenacion
	$scope.ordenar = function(col) {
	    ordenarTabla($scope.datos.ordenacion, col);	
    };
    $scope.iconoOrdenacion = function(col) {
        return iconoOrdenacionTabla($scope.datos.ordenacion, col);
    };
    
    $scope.cancel = function () {
        $uibModalInstance.dismiss('cancel');
    };
    
    $scope.aceptar = function () {
        $uibModalInstance.close('ok');
    };
    
    $scope.seleccionar = function (obj) {
        $uibModalInstance.close(obj);
    };
    
    // Funciones de paginacion
	$scope.setPagina = function() {
		setPagina($scope.datos.paginacion);
	};
});

