'use strict';

var app = angular.module('WSNWebInterface');

app.controller('AdmListadoController', ['$scope', '$filter', '$uibModal', 'wsnWebInterfaceAdmFactory', 'regXPagina', 'tiempoInactiva', function($scope, $filter, $uibModal, wsnWebInterfaceAdmFactory, regXPagina, tiempoInactiva) {
	$scope.motas = [];
	$scope.paginas = [];
	$scope.ordenacion = getOrdenacion();
	$scope.paginacion = getPaginacion(regXPagina);
    $scope.buscador = '';
    $scope.mensajeAlerta;
    mensajes($scope);
	
	// Inicializacion del controlador
	var init = function() {
        var loading = cargando($uibModal);
        loading.opened.then(function() {
            wsnWebInterfaceAdmFactory.motas().then(
                function(res) {
                    loading.close();
                    // Recupera los datos
                    $scope.motas = res.data;
                    var fecAct = (new Date()).getTime() - tiempoInactiva; // Fecha actual menos una hora
                    angular.forEach($scope.motas, function(d){ 
                        var fec = new Date(d.fechaInfo);
                        d.inactiva = fec < fecAct;
                        d.nueva = !d.sinc;
                        d.desincronizada = d.sinc && d.sinc != d.sincMota;
                    });
                    // Prepara la paginacion
                    $scope.preparaPaginacion();
                },
                function(error) {
                    loading.close();
                    console.log(error);
                    setMensajeError($scope, error);
                }	
            );
        });
	};
	init();
	
	// Funcion de ordenacion
	$scope.ordenar = function(col) {
	    ordenarTabla($scope.ordenacion, col);	
    };
    $scope.iconoOrdenacion = function(col) {
        return iconoOrdenacionTabla($scope.ordenacion, col);
    };
  
	// Funciones de paginacion
	$scope.setPagina = function() {
        setPagina($scope.paginacion);
	};
    $scope.preparaPaginacion = function() {
        preparaPaginacion($scope.paginacion, $filter, $scope.motas, $scope.buscador);
    };
    
    // Funcion de eliminar la motas
    $scope.eliminarMota = function(mota) {
        var confirmar = solicitarConfirmacion($uibModal, '¿Desea eliminar la mota?');
        confirmar.result.then(
          function(ok) {
              if (ok === 'ok') {
                var loading = cargando($uibModal);
                limpiarMensajes($scope);
                wsnWebInterfaceAdmFactory.borrarMota(mota.id).then(
                    function(res) {
                        loading.close();
                        setMensaje($scope, "Mota eliminada correctamente");
                        $scope.motas.splice($scope.motas.indexOf(mota), 1);
                        $scope.preparaPaginacion();
                    },
                    function(error) {
                        loading.close();
                        console.log(error);
                        setMensajeError($scope, error);
                    }	
                );
              }
        });
    };
    
    // Funcion de seleccionar la mota para ver sus valores de status
	$scope.seleccionarMota = function(mota) {
		$scope.mota_seleccionada = {};
		$scope.mota_seleccionada.ordenacion = getOrdenacion();
        $scope.mota_seleccionada.mota = mota;
		  
        var loading = cargando($uibModal);
        limpiarMensajes($scope);
        wsnWebInterfaceAdmFactory.valoresStatus(mota.id).then(
			function(req) {
				$scope.mota_seleccionada.status = req.data;
                loading.close();
                $uibModal.open({
                    templateUrl: 'vistas/utilidades/valoresStatus.html',
                    controller: 'ModalControler',
                    resolve: {
                        datos: function () {
                            return $scope.mota_seleccionada;
                        }
                    }
                });
			},
			function(error) {
                loading.close();
				console.log(error);
                setMensajeError($scope, error);
			}
		);
	};
}]);

app.controller('AdmConfiguracionController', ['$scope', '$filter', '$uibModal', 'wsnWebInterfaceAdmFactory', 'wsnWebInterfaceFactory', 'regXPagina', function($scope, $filter, $uibModal, wsnWebInterfaceAdmFactory, wsnWebInterfaceFactory, regXPagina) {
    $scope.motas = [];
	$scope.paginas = [];
	$scope.ordenacion = getOrdenacion();
	$scope.paginacion = getPaginacion(regXPagina);
    $scope.buscador = '';
    $scope.parametros = []
    mensajes($scope);
    
    // Inicializacion del controlador
	var init = function() {
        var loading = cargando($uibModal);
        loading.opened.then(function() {
            wsnWebInterfaceAdmFactory.motas().then(
                function(res) {
                    loading.close();
                    // Recupera los datos
                    $scope.motas = res.data;
                    // Prepara la paginacion
                    $scope.preparaPaginacion();
                },
                function(error) {
                    loading.close();
                    console.log(error);
                    setMensajeError($scope, error);
                }	
            );
        });
	};
	init();
	
	// Funcion de ordenacion
	$scope.ordenar = function(col) {
	    ordenarTabla($scope.ordenacion, col);	
    };
    $scope.iconoOrdenacion = function(col) {
        return iconoOrdenacionTabla($scope.ordenacion, col);
    };
  
	// Funciones de paginacion
	$scope.setPagina = function() {
        setPagina($scope.paginacion);
	};
    $scope.preparaPaginacion = function() {
        preparaPaginacion($scope.paginacion, $filter, $scope.motas, $scope.buscador);
    };
    
    // Funcion de seleccionar la mota para ver sus valores de status
	$scope.seleccionarMota = function(mota) {
		$scope.mota_seleccionada = mota;
        $scope.parametros = [];
        $scope.aMOTAparams = [];
        var loading = cargando($uibModal);
        limpiarMensajes($scope);
        loading.opened.then(function() {
            wsnWebInterfaceFactory.parametros().then(
                function(req) {
                    wsnWebInterfaceAdmFactory.recuperaParametros(mota.id).then(
                        function(req1) {
                            var params = [], MOTAparams=[];                     
                            angular.forEach(req1.data, function(d) {
                                var iCnt = 0;
                                for (iCnt = 0; iCnt < req.data.length; iCnt++)
                                    if (d.id === req.data[iCnt].id)
                                        break;
                                params.push({"id":d.id, "valor":d.valor, "p": req.data[iCnt]});
                                if (req.data[iCnt].mota)
                                    MOTAparams.push(req.data[iCnt].id); 
                            });
                            $scope.parametros = params;
                            $scope.aMOTAparams = MOTAparams;
                            loading.close();
                        },
                        function(error) {
                            loading.close();
                            console.log(error);
                            setMensajeError($scope, error);
                        }
                    );
                },
                function(error) {
                    loading.close();
                    console.log(error);
                    setMensajeError($scope, error);
                }
            );
        });
	};
    
    $scope.cancelar = function() {
        $scope.parametros = [];
    };
    
    $scope.guardar = function() {
        var confirmar = solicitarConfirmacion($uibModal, '¿Desea modificar la configuración?');
        confirmar.result.then(
          function(ok) {
              if (ok === 'ok') {
                var params = [];
                angular.forEach($scope.parametros, function(d) { params.push({"id":d.id ,"valor":d.valor})});       
                var loading = cargando($uibModal);
                limpiarMensajes($scope);
                loading.opened.then(function() {
                    wsnWebInterfaceAdmFactory.modificarParametros($scope.mota_seleccionada.id, params).then(
                        function(ok) {
                            setMensaje($scope, "Configuración modificada correctamente");
                            $scope.parametros = [];
                            loading.close();
                        },
                        function(error) {
                            loading.close();
                            console.log(error);
                            setMensajeError($scope, error);
                        }
                    );
                });
              }
          }
        );
    };
    
    $scope.guardarTodasMotas = function() {
        var confirmar = solicitarConfirmacion($uibModal, '¿Desea sincronizar las motas?');
        confirmar.result.then(
          function(ok) {
              if (ok === 'ok') {
                var params = [];
                angular.forEach($scope.parametros, function(d) { if ($scope.aMOTAparams.indexOf(d.id) >= 0) params.push({"id":d.id ,"valor":d.valor})});
                var loading = cargando($uibModal);
                limpiarMensajes($scope);
                loading.opened.then(function() {
                    wsnWebInterfaceAdmFactory.modificarParametrosTodasMotas(params).then(
                        function(ok) {
                            setMensaje($scope, "Sincronización realizada correctamente");
                            $scope.parametros = [];
                            loading.close();
                        },
                        function(error) {
                            loading.close();
                            console.log(error);
                            setMensajeError($scope, error);
                        }
                    );
                });
              }
          }
        );
    };

}]);

app.controller('AdmTablasController', ['$scope', '$filter', '$uibModal', 'wsnWebInterfaceAdmAppFactory', function($scope, $filter, $uibModal, wsnWebInterfaceAdmAppFactory) {
    $scope.tabla;
    $scope.tablas = ['parametros', 'tipos_parametro', 'sensores', 'status'];
    $scope.datos = [];
    $scope.ordenacion = getOrdenacion();
    mensajes($scope);

    function consultar(loading) {
        wsnWebInterfaceAdmAppFactory.consultar($scope.tabla).then(
            function(req) {
                $scope.datos = req.data;
                loading.close();
            },
            function(error) {
                loading.close();
                console.log(error);
                setMensajeError($scope, error);
            }
        );
    };
    
    function clone(dato) {
        var dator = {};
        dator.id = dato.id;
		dator.descripcion = dato.descripcion;
        dator.longitud = dato.longitud;
        dator.id_tipos_parametro = dato.id_tipos_parametro;
        dator.mota = dato.mota;
        dator.valor_critico = dato.valor_critico;
        dator.comparacion = dato.comparacion;
        dator.alerta = dato.alerta;
        dator.usuario = dato.usuario;
        dator.password = dato.password;
		dator.interfaz = dato.interfaz;
        dator.unidades = dato.unidades;
        dator.conversion = dato.conversion;
        dator.defecto = dato.defecto;
        return dator;
    }
    
    // Funcion de inicializacion de la adm de usuarios
    $scope.initUsuarios = function() {
        $scope.tabla = 'usuarios';
        $scope.cargaTabla();
    };
    
    // Funcion de consulta de datos
    $scope.cargaTabla = function() {
        var loading = cargando($uibModal);
        loading.opened.then(function() {
            limpiarMensajes($scope);
            $scope.dato = {};
            $scope.dato_seleccionado = false;
            consultar(loading);
        });
    };
    
    // Funcion de ordenacion
	$scope.ordenar = function(col) {
	    ordenarTabla($scope.ordenacion, col);	
    };
    $scope.iconoOrdenacion = function(col) {
        return iconoOrdenacionTabla($scope.ordenacion, col);
    };
    
    // Funciones de seleccion del dato
    $scope.seleccionar = function(dato) {
        limpiarMensajes($scope);
        $scope.dato = clone(dato);
		$scope.dato_seleccionado = true;
    };
    
    // Funciones de formulario
    $scope.cancelar = function() {
        limpiarMensajes($scope);
        $scope.dato = {};
    };
    
    $scope.guardar = function() {
		var confirmar = solicitarConfirmacion($uibModal, '¿Desea guardar el dato?');
        confirmar.result.then(
          function(ok) {
              if (ok === 'ok') {
				var loading = cargando($uibModal);
				limpiarMensajes($scope);
				loading.opened.then(function() {
					wsnWebInterfaceAdmAppFactory.guardar($scope.tabla, $scope.dato).then(
						function(req) {
							$scope.dato = {};
							consultar(loading);
							setMensaje($scope, "Dato guardado correctamente");
						},
						function(error) {
							loading.close();
							console.log(error);
							setMensajeError($scope, error);
						}
					);
				});
			  }
		  }
	    );
    };
    
    $scope.borrar = function(dato) {
		var confirmar = solicitarConfirmacion($uibModal, '¿Desea eliminar el dato?');
        confirmar.result.then(
          function(ok) {
              if (ok === 'ok') {
				var loading = cargando($uibModal);
				limpiarMensajes($scope);
				loading.opened.then(function() {
					wsnWebInterfaceAdmAppFactory.borrar($scope.tabla, $scope.tabla === 'usuarios' ? dato.usuario : dato.id).then(
						function(req) {
							$scope.dato = {};
							consultar(loading);
							setMensaje($scope, "Dato eliminado correctamente");
						},
						function(error) {
							loading.close();
							console.log(error);
							setMensajeError($scope, error);
						}
					);
				});
			  }
		  }
		);
    };
}]);

app.controller('AdmCambioMapaController', ['$scope', '$filter', '$uibModal', 'wsnWebInterfaceAdmFactory', function($scope, $filter, $uibModal, wsnWebInterfaceAdmFactory) {
	$scope.dato = {};
    mensajes($scope);
	
	$scope.guardar = function() {
		var confirmar = solicitarConfirmacion($uibModal, '¿Desea modificar el mapa?');
        confirmar.result.then(
          function(ok) {
              if (ok === 'ok') {
				var loading = cargando($uibModal);
				limpiarMensajes($scope);
				loading.opened.then(function() {
					wsnWebInterfaceAdmFactory.modificarMapa($scope.dato).then(
						function(req) {
							loading.close();
							$scope.dato = {};
							$scope.fichero = undefined;
							setMensaje($scope, "Dato guardado correctamente");
						},
						function(error) {
							loading.close();
							console.log(error);
							setMensajeError($scope, error);
						}
					);
				});
			  }
		  }
		);
    };
	
	$scope.click = function() {
		document.getElementById("fichero_png").onchange = function() {
			var f = document.getElementById('fichero_png').files[0], r = new FileReader();
			if (f) {	
				r.onloadend = function(e){
					$scope.dato.mapa = btoa(e.target.result);
					$scope.fichero = f.name;
					$scope.$digest();
				}
				r.readAsBinaryString(f);
			}
		}
		document.getElementById("fichero_png").click();
	};

	// Funciones de formulario
    $scope.cancelar = function() {
        limpiarMensajes($scope);
        $scope.dato = {};
    };
}]);

app.controller('AdmMapaController', ['$scope', '$filter', '$uibModal', 'wsnWebInterfaceAdmFactory', 'wsnWebInterfaceFactory', 'XYparams', function($scope, $filter, $uibModal, wsnWebInterfaceAdmFactory, wsnWebInterfaceFactory, XYparams) {
    $scope.motas = [];
    $scope.administracionMapa = true;
    mensajes($scope);
    
    // Inicializacion del controlador
	var init = function() {
        var loading = cargando($uibModal);
        loading.opened.then(function() {
            wsnWebInterfaceAdmFactory.motas().then(
                function(res) {
					wsnWebInterfaceFactory.mapaDim().then(
						function(res2) {
                            loading.close();
                            $scope.motas = res.data;
                            // Prepara el mapa
                            mapa(res2.data[0]);
                        },
                        function(error) {
                            loading.close();
                            console.log(error);
                            setMensajeError($scope, error);
                        }
                    );
                },
                function(error) {
                    loading.close();
                    console.log(error);
                    setMensajeError($scope, error);
                }	
            );  
        });
	};
	init();
    
    function mapa(dim) {
        creaMapa($scope, dim.X, dim.Y, wsnWebInterfaceFactory.mapaImg());
    };
    
    $scope.salvar = function() {
        var iCnt = 0;
        var loading;
        var error = '';
		var confirmar = solicitarConfirmacion($uibModal, '¿Desea modificar la posición de las motas?');
        confirmar.result.then(
          function(ok) {
              if (ok === 'ok') {
				$scope.vector.forEachFeature(function(f) {
					var coords = f.getGeometry().getCoordinates();
					var oldCoords = [f.__mota.X, f.__mota.Y];
					
					if (Math.abs(coords[0]-oldCoords[0]) > 10 || Math.abs(coords[1]-oldCoords[1])) {
						// Se ha movido la mota
						iCnt++;
						if (!loading) {
							 loading = cargando($uibModal);
							 limpiarMensajes($scope);
						}
						var coordenadas = [{"id":XYparams[0], "valor": Math.ceil(coords[0])}, {"id":XYparams[1], "valor": Math.ceil(coords[1])}];
						wsnWebInterfaceAdmFactory.modificarParametros(f.__mota.id, coordenadas).then(
							function(ok) {
								iCnt--;
								f.__mota.X = coords[0];
								f.__mota.Y = coords[1];
								if (iCnt == 0) {
									loading.close();
									pintaMensajes(error);    
								}
							},
							function(err) {
								iCnt--;
								error += f.__mota.desc + '('+f.__mota.ip+') ';
								if (iCnt == 0) {
									loading.close();
									pintaMensajes(error);    
								}
							}
						);  
					}
				});
			  }
	      }
		);
        
        function pintaMensajes(error) {
            limpiarMensajes($scope);
            if (error) {
                var err = {statusText: "Error al modificar la localización de las motas :" + error};
                setMensajeError($scope, err);
            }else {
                setMensaje($scope, "Localización modificada correctamente");
            }
        }
    };
    
    $scope.descargarImagen = function() {
        var img = document.getElementById("descargarImagen");
        $scope.map.once('postcompose', function(event) {
            var canvas = event.context.canvas;
            img.href = canvas.toDataURL('image/png');
        });
        $scope.map.renderSync();
    };

    $scope.seleccionarMapa = function() {
        var f = document.getElementById("ficheroMapa");
        f.onchange = function(){
            var ff = document.getElementById('ficheroMapa').files[0],
                 r = new FileReader();
            if (ff) {	
                r.onloadend = function(e){
                    var loading = cargando($uibModal);
                    limpiarMensajes($scope);
                    loading.opened.then(function() {
                        wsnWebInterfaceAdmFactory.modificarMapa({"contenido": btoa(e.target.result)}).then(
                                function(res) {
                                    loading.close();
                                    setMensaje($scope, "Mapa modificado correctamente; recargue la página para ver los cambios");
                                },
                                function(error) {
                                    loading.close();
                                    console.log(error);
                                    setMensajeError($scope, error);
                                }	
                        );
                    });
                };
                r.readAsBinaryString(ff);
            }
        };
        f.click();
    };
}]);
