'use strict';

var app = angular.module('WSNWebInterface');

app.controller('ConsultaController', ['$scope', '$filter', '$uibModal', 'wsnWebInterfaceFactory', 'regXPagina', function($scope, $filter, $uibModal, wsnWebInterfaceFactory, regXPagina) {
	$scope.motas = [];
	$scope.ordenacion = getOrdenacion();
	$scope.paginacion = getPaginacion(regXPagina);
	$scope.mota_seleccionada;
    $scope.buscador = '';
    mensajes($scope);
	
	// Inicializacion del controlador
	var init = function() {
        var loading = cargando($uibModal);
        loading.opened.then(function() {
            wsnWebInterfaceFactory.motas().then(
                function(res) {
                    // Recupera los datos
                    $scope.motas = res.data;
                    // Prepara la paginacion
                    $scope.preparaPaginacion();
                    loading.close();
                },
                function(error) {
                    loading.close();
                    console.log(error);
                    setMensajeError($scope, error);
                }	
            );
        });
	};
	init();
	
	// Funcion de ordenacion
	$scope.ordenar = function(col) {
	    ordenarTabla($scope.ordenacion, col);	
    };
    $scope.iconoOrdenacion = function(col) {
        return iconoOrdenacionTabla($scope.ordenacion, col);
    };
  
	// Funciones de paginacion
	$scope.setPagina = function() {
		setPagina($scope.paginacion);
	};
    $scope.preparaPaginacion = function() {
        preparaPaginacion($scope.paginacion, $filter, $scope.motas, $scope.buscador);
    };
  
	// Funcion de seleccionar la mota para ver sus valores
	$scope.seleccionarMota = function(mota) {
		$scope.mota_seleccionada = {};
		$scope.mota_seleccionada.ordenacion = getOrdenacion();
        $scope.mota_seleccionada.mota = mota;
		  
        var loading = cargando($uibModal);
        limpiarMensajes($scope);
        loading.opened.then(function() {
            wsnWebInterfaceFactory.valoresSensores(mota.id).then(
                function(req) {
                    $scope.mota_seleccionada.sensores = req.data;
                    loading.close();
                    $uibModal.open({
                        templateUrl: 'vistas/utilidades/valoresSensores.html',
                        controller: 'ModalControler',
                        resolve: { datos: function () { return $scope.mota_seleccionada; } }
                    });
                },
                function(error) {
                    loading.close();
                    console.log(error);
                    setMensajeError($scope, error);
                }
            );
        });
	};

}]);


app.controller('MapaController', ['$scope', '$filter', '$uibModal', 'wsnWebInterfaceFactory', function($scope, $filter, $uibModal, wsnWebInterfaceFactory) {
    $scope.motas = [];
    mensajes($scope);
    
    // Inicializacion del controlador
	var init = function() {
        var loading = cargando($uibModal);
        loading.opened.then(function() {
            wsnWebInterfaceFactory.motas().then(
                function(res) {
                    // Recupera los datos
                    wsnWebInterfaceFactory.mapaDim().then(
                        function(res2) {
                            loading.close();
                            $scope.motas = res.data;
                            // Prepara el mapa
                            mapa(res2.data[0]);
                        },
                        function(error) {
                            loading.close();
                            console.log(error);
                            setMensajeError($scope, error);
                        }
                    );	
                },
                function(error) {
                    loading.close();
                    console.log(error);
                    setMensajeError($scope, error);
                }	
            );
        });
	};
	init();
    
    function mapa(dim) {
        $scope.onClickMapa = function(mota) {
            $scope.mota_seleccionada = {"mota": mota, "ordenacion": getOrdenacion()};
            var loading = cargando($uibModal);
            limpiarMensajes($scope);
            loading.opened.then(function() {
                wsnWebInterfaceFactory.valoresSensores(mota.id).then(
                    function(req) {
                        $scope.mota_seleccionada.sensores = req.data;
                        loading.close();
                        $uibModal.open({
                            templateUrl: 'vistas/utilidades/valoresSensores.html',
                            controller: 'ModalControler',
                            resolve: {
                                datos: function () {
                                    return $scope.mota_seleccionada;
                                }
                            }
                        });
                    },
                    function(error) {
                        loading.close();
                        console.log(error);
                        setMensajeError($scope, error);
                    }
                );
            }); 
        };
        
        creaMapa($scope, dim.X, dim.Y, wsnWebInterfaceFactory.mapaImg());
    };
    
    $scope.descargarImagen = function() {
        var img = document.getElementById("descargarImagen");
        $scope.map.once('postcompose', function(event) {
            var canvas = event.context.canvas;
            img.href = canvas.toDataURL('image/png');
        });
        $scope.map.renderSync();
    };
}]);


app.controller('HistoricoController', ['$scope', '$filter', '$uibModal', 'wsnWebInterfaceFactory', 'regXPagina', function($scope, $filter, $uibModal, wsnWebInterfaceFactory, regXPagina) {
    $scope.motas = [];
	$scope.sensores = [];
    $scope.valores = [];
	$scope.motaSeleccionada;
	$scope.sensorSeleccionado;
    $scope.limite = 15;
    mensajes($scope);
    
    // Inicializacion del controlador
	var init = function() {
        var loading = cargando($uibModal);
        loading.opened.then(function() {
            wsnWebInterfaceFactory.motas().then(
                function(res) {
                    // Recupera los datos
                    $scope.motas = res.data;
                    loading.close();
                },
                function(error) {
                    loading.close();
                    console.log(error);
                    setMensajeError($scope, error);
                }	
            );
        });
	};
	init();
    
    // Seleccionar la mota
    $scope.seleccionarMota = function() {
        var modal = $uibModal.open({
            templateUrl: 'vistas/utilidades/seleccionMota.html',
            controller: 'ModalControler',
            resolve: {
                datos: function () {
                    return {motas: $scope.motas, ordenacion: getOrdenacion(), paginacion: getPaginacion(regXPagina)};
                }
            }
        });
        
        modal.result.then(
          function(obj) {
              $scope.motaSeleccionada = obj;
              $scope.motaSeleccionada.val = $scope.motaSeleccionada.desc + ' (' + $scope.motaSeleccionada.ip + ')';
              $scope.valores = null;
              $scope.seleccionarSensor();
          }  
        );
    };
    
    // Cargar los sensores
    $scope.seleccionarSensor = function() {
        var loading = cargando($uibModal);
        limpiarMensajes($scope);
        loading.opened.then(function() {
            wsnWebInterfaceFactory.valoresSensores($scope.motaSeleccionada.id).then(
                function(res) {
                    // Recupera los datos
                    $scope.sensores = res.data;
                    loading.close();
                },
                function(error) {
                    loading.close();
                    console.log(error);
                    setMensajeError($scope, error);
                }	
            );
        });
    };
    
    // Cargar los valores
    $scope.seleccionarValores = function() {
        if ($scope.motaSeleccionada && $scope.sensorSeleccionado) {
            var loading = cargando($uibModal);
            limpiarMensajes($scope);
            wsnWebInterfaceFactory.historicoSensor($scope.motaSeleccionada.id, $scope.sensorSeleccionado.id, $scope.limite).then(
                function(res) {
                    // Recupera los datos
                    $scope.valores = res.data;
                    loading.close();
                    
                    // Pinta la grafica
                    var data = [
                        {
                            x: $scope.valores.map(function(d){ return d.fecha; }),
                            y: $scope.valores.map(function(d){ return d.valor; }),
                            type: 'scatter'
                        }
                    ];
                    Plotly.newPlot('grafico', data);
                },
                function(error) {
                    loading.close();
                    console.log(error);
                    setMensajeError($scope, error);
                    console.log($scope.mensajes);
                }
		    );
        }
    };
}]);

