/// -------------------------------------------------------------------------
/// Codigo copiado de los ejemplos de OpenLayers
/// http://openlayers.org/en/v3.7.0/examples/drag-features.html
Drag = function() {
    ol.interaction.Pointer.call(this, {
        handleDownEvent: Drag.prototype.handleDownEvent,
        handleDragEvent: Drag.prototype.handleDragEvent,
        handleMoveEvent: Drag.prototype.handleMoveEvent,
        handleUpEvent: Drag.prototype.handleUpEvent
    });

    this.coordinate_ = null;
    this.cursor_ = 'pointer';
    this.feature_ = null;
    this.previousCursor_ = undefined;

};
ol.inherits(Drag, ol.interaction.Pointer);

Drag.prototype.handleDownEvent = function(evt) {
    var map = evt.map;
    if (map.__popup) {
        map.__popup.setPosition(undefined);
    }
    map.__onDrag = true;
    var feature = map.forEachFeatureAtPixel(evt.pixel,
        function(feature) { return feature; }
    );

    if (feature) {
        this.coordinate_ = evt.coordinate;
        this.feature_ = feature;
    }
    return !!feature;
};

Drag.prototype.handleDragEvent = function(evt) {
    var deltaX = evt.coordinate[0] - this.coordinate_[0];
    var deltaY = evt.coordinate[1] - this.coordinate_[1];

    var geometry = /** @type {ol.geom.SimpleGeometry} */
            (this.feature_.getGeometry());
    geometry.translate(deltaX, deltaY);

    this.coordinate_[0] = evt.coordinate[0];
    this.coordinate_[1] = evt.coordinate[1];
};

Drag.prototype.handleMoveEvent = function(evt) {
    if (this.cursor_) {
        var map = evt.map;
        var feature = map.forEachFeatureAtPixel(evt.pixel,
            function(feature) { return feature; }
        );
        var element = evt.map.getTargetElement();
        if (feature) {
            if (element.style.cursor != this.cursor_) {
              this.previousCursor_ = element.style.cursor;
              element.style.cursor = this.cursor_;
            }
        } else if (this.previousCursor_ !== undefined) {
            element.style.cursor = this.previousCursor_;
            this.previousCursor_ = undefined;
        }
    }
};

Drag.prototype.handleUpEvent = function(evt) {
    var map = evt.map;
    map.__onDrag = false;
    this.coordinate_ = null;
    this.feature_ = null;
    return false;
};
/// -------------------------------------------------------------------------

function exportImg(map, img) {
    map.once('postcompose', function(event) {
        var canvas = event.context.canvas;
        img.href = canvas.toDataURL('image/png');
    });
    map.renderSync();
}
	
function creaMapa($scope, Xdim, Ydim, img) {
     var extent = [0, 0, Xdim, Ydim];
     var projection = new ol.proj.Projection({ code: 'xkcd-image', units: 'pixels', extent: extent });
	  
	 $scope.vector = new ol.source.Vector();
     var yoffset = 0;
	 for (var iCnt = 0; iCnt < $scope.motas.length; iCnt++) {
	  	var d = $scope.motas[iCnt];
        d.X = parseInt(d.X);
        d.Y = parseInt(d.Y); 
	  	var txt = d.desc;
        if (d.X === 0 && d.Y === 0) {
            d.Y += yoffset;
            yoffset += 40;
        }
	  	var coord = [d.X, d.Y];
	  	var feature = new ol.Feature({ geometry: new ol.geom.Point(coord), name: d.desc});
        var textStyle = new ol.style.Text({text: d.desc, offsetY:-10, scale:1.3});
        if (d.alerta) {
            textStyle.setFill(new ol.style.Fill({color: '#F00'}));
            textStyle.setScale(1.5);
        }
		feature.setStyle( new ol.style.Style({ image:new ol.style.Icon({src:'./imagenes/icono.png'}), text: textStyle}) );
	  	feature.__mota = d;
	  	$scope.vector.addFeature(feature);
	 }
     var vl = new ol.layer.Vector({source:$scope.vector});
     
     var interactions = undefined;
     if ($scope.administracionMapa) {
         interactions = ol.interaction.defaults().extend([new Drag()]);
     }

     $scope.map = new ol.Map({
        interactions: interactions,
        layers: [
          new ol.layer.Image({
            source: new ol.source.ImageStatic({ url: img, projection: projection, imageExtent: extent })
          }),
		  vl
        ],
        target: 'map',
        view: new ol.View({
          projection: projection,
          center: ol.extent.getCenter(extent),
          zoom: 1,
          maxZoom: 8
        })
      });
      
      if (document.getElementById('popup')) {
        var popup = new ol.Overlay({
		  element: document.getElementById('popup'),
		  autoPan: true,
		  autoPanAnimation: { duration: 250 }
		});
		$scope.map.addOverlay(popup);
        $scope.map.__popup = popup;

		$scope.map.on('pointermove', function(evt) {
            if (evt.map.__onDrag) return;

			var ft = null;
			evt.map.forEachFeatureAtPixel(evt.pixel, function(feature) {
			  ft = feature;
			});
			if (ft && ft.__mota && ft.__mota.nota && '-' !== ft.__mota.nota) {
				var txt = '<pre>' + ft.__mota.nota;
                if (ft.__mota.alerta) txt += '<br/><span style="color:red">'+ft.__mota.alerta+'</span>';
                txt += '</pre>';
                document.getElementById('popup').innerHTML = txt
				popup.setPosition(ol.extent.getCenter(ft.U.geometry.getExtent()));
			}
			else
				popup.setPosition(undefined);
		});
      }
	  
      if ($scope.onClickMapa) {
        $scope.map.on('click', function(evt) {
            var feature = $scope.map.forEachFeatureAtPixel(evt.pixel,
                function(feature, layer) {
                    return feature;
                }
            );
            if (feature) {
               $scope.onClickMapa(feature.__mota);
            }
        });
      };
      
      
 }
 