'use strict';
var app = angular.module('WSNWebInterface');

app.factory('wsnWebInterfaceFactory', ['$http', '$location', 'baseURL', function($http, $location, baseURL) {
	var wsnWebInterfaceFactory = {};
	
	wsnWebInterfaceFactory.sensores = function() {
		return $http.get(baseURL + "sensores");
	};
	
	wsnWebInterfaceFactory.parametros = function() {
		return $http.get(baseURL + "parametros");
	};
	
	wsnWebInterfaceFactory.motas = function() {
		return $http.get(baseURL + "motas");
	};
	
	wsnWebInterfaceFactory.valoresSensores = function(idMota) {
		return $http.get(baseURL + "motas/" + idMota + "/valores");
	};
    
    wsnWebInterfaceFactory.historicoSensor = function(idMota, idSensor, limite) {
		return $http.get(baseURL + "motas/" + idMota + "/valores/" + idSensor + '/' + limite);
	};
    
    wsnWebInterfaceFactory.mapaDim = function() {
		return $http.get(baseURL + "mapa/info");
	};
    
    wsnWebInterfaceFactory.mapaImg = function() {
        if (baseURL.startsWith('http'))
            return baseURL + "mapa";
        else
            return $location.protocol() + '://' + $location.host() + ':' + $location.port() + baseURL + "mapa";
    }
	
	return wsnWebInterfaceFactory;
}]);


app.factory('wsnWebInterfaceAdmFactory', ['$http', 'baseURL', function($http, baseURL) {
	var wsnWebInterfaceAdmFactory = {};
    
    var baseURLAdm = baseURL + "adm/"
	
	wsnWebInterfaceAdmFactory.motas = function() {
		return $http.get(baseURLAdm + "motas");
	};
    
    wsnWebInterfaceAdmFactory.borrarMota = function(idMota) {
		return $http.delete(baseURLAdm + "motas/" + idMota);
	};
    
    wsnWebInterfaceAdmFactory.valoresStatus = function(idMota) {
		return $http.get(baseURLAdm + "motas/" + idMota + "/status");
	};
    
    wsnWebInterfaceAdmFactory.recuperaParametros = function(idMota) {
        return $http.get(baseURLAdm + "motas/" + idMota + "/configuracion");
    };
    
    wsnWebInterfaceAdmFactory.modificarParametros = function(idMota, parametros) {
        return $http.put(baseURLAdm + "motas/" + idMota + "/configuracion", parametros);
    };
    
    wsnWebInterfaceAdmFactory.modificarParametrosTodasMotas = function(parametros) {
        return $http.put(baseURLAdm + "motas/configuracion", parametros);
    };
    
    wsnWebInterfaceAdmFactory.modificarMapa = function(mapa) {
        return $http.post(baseURL + "mapa", mapa);
    };

	return wsnWebInterfaceAdmFactory;
}]);

app.factory('wsnWebInterfaceLoginFactory', ['$http', 'baseURL', function($http, baseURL) {
    var wsnWebInterfaceLoginFactory = {};
    
    wsnWebInterfaceLoginFactory.login = function(usuario, password) {
		return $http.post(baseURL + "login", {"usuario":usuario, "password":password});
	};
    
     wsnWebInterfaceLoginFactory.getLogin = function() {
		return $http.get(baseURL + "login");
	};
    
    wsnWebInterfaceLoginFactory.logout = function() {
		return $http.delete(baseURL + "login");
	};
    
    return wsnWebInterfaceLoginFactory;
}]);


app.factory('wsnWebInterfaceAdmAppFactory', ['$http', 'baseURL', function($http, baseURL) {
	var wsnWebInterfaceAdmAppFactory = {};
    
    var baseURLAdmTablas = baseURL + "administracion/"
    
    wsnWebInterfaceAdmAppFactory.consultar = function(tabla) {
        return $http.get(baseURLAdmTablas + tabla);
    };
    
    wsnWebInterfaceAdmAppFactory.guardar = function(tabla, dato) {
        return $http.post(baseURLAdmTablas + tabla, dato);
    };
    
    wsnWebInterfaceAdmAppFactory.borrar = function(tabla, id) {
        return $http.delete(baseURLAdmTablas + tabla + "/" + id);
    };

    return wsnWebInterfaceAdmAppFactory;
}]);

app.factory('wsnWebInterfaceDataFactory', function() {
    var wsnWebInterfaceDataFactory = {}
    
    var usuarioLogado;
    
    wsnWebInterfaceDataFactory.getUsuarioLogado = function() {
        return usuarioLogado;
    }
    
    wsnWebInterfaceDataFactory.setUsuarioLogado = function(usuario) {
        usuarioLogado = usuario;
    };
    
    return wsnWebInterfaceDataFactory;
});