describe('Controllers', function() {
	beforeEach(module('WSNWebInterface'));
	
	beforeEach(inject(function($httpBackend, baseURL){
		$httpBackend.expectGET(baseURL + 'login').respond(200, {});
		$httpBackend.flush();
	}));
	 
	describe('LoginCabeceraController', function() {

	  var controller, $scope, wsnWebInterfaceDataFactory;

	  beforeEach(inject(function(_$controller_, $rootScope, _wsnWebInterfaceDataFactory_){
		$scope = $rootScope.$new();
		wsnWebInterfaceDataFactory = _wsnWebInterfaceDataFactory_;

		controller = _$controller_('LoginCabeceraController', { '$scope': $scope, 'wsnWebInterfaceDataFactory':wsnWebInterfaceDataFactory });
	  }));
	  
	  it('cambio usuario', inject(function(wsnWebInterfaceDataFactory) {	  
		expect(controller).toBeDefined();
		expect(wsnWebInterfaceDataFactory);
		expect(wsnWebInterfaceDataFactory.getUsuarioLogado()).toBeUndefined();
		expect($scope.cabecera).toBe('Login');
		expect($scope.icono).toBe('glyphicon glyphicon-log-in');
		
		wsnWebInterfaceDataFactory.setUsuarioLogado("4444");
		$scope.$digest();
		expect($scope.cabecera).toBe('4444');
		expect($scope.icono).toBe('glyphicon glyphicon-log-out');
		
		wsnWebInterfaceDataFactory.setUsuarioLogado(null);
		$scope.$digest();
		expect($scope.cabecera).toBe('Login');
		expect($scope.icono).toBe('glyphicon glyphicon-log-in');
	  }));
	});

	describe('LoginController', function() {
	  
	  var $uibModal = {open: function() { return {opened: {then: function (f){f();}}, close: function() {}}}};
	  var controller, $scope, wsnWebInterfaceDataFactory, wsnWebInterfaceLoginFactory, $httpBackend, baseURL;

	  beforeEach(inject(function(_$controller_, $rootScope, _$httpBackend_, _wsnWebInterfaceDataFactory_, _wsnWebInterfaceLoginFactory_, _baseURL_){
		$scope = $rootScope.$new();
		wsnWebInterfaceDataFactory = _wsnWebInterfaceDataFactory_;
		wsnWebInterfaceLoginFactory = _wsnWebInterfaceLoginFactory_;
		$httpBackend = _$httpBackend_;
		baseURL = _baseURL_;
		
		controller = _$controller_('LoginController', { '$scope': $scope, '$uibModal': $uibModal, 'wsnWebInterfaceLoginFactory':wsnWebInterfaceLoginFactory, 'wsnWebInterfaceDataFactory':wsnWebInterfaceDataFactory });
	  }));
	  
	  it('login', inject(function(wsnWebInterfaceDataFactory) {
	    expect(controller).toBeDefined();
		expect(wsnWebInterfaceDataFactory);
		expect(wsnWebInterfaceDataFactory.getUsuarioLogado()).toBeUndefined();
		expect($scope.logado).toBe(false);
		expect($scope.mensaje_cabecera).toBe('Página de login');

		$scope.usuario = "4444";
		$scope.password = "4444";
		$httpBackend.expectPOST(baseURL + 'login', {"usuario":$scope.usuario, "password":$scope.password}).respond(200, {});
		$scope.login();
		$httpBackend.flush();

		expect($scope.logado).toBe(true);
		expect($scope.mensaje_cabecera).toBe('Ya esta logado como '+$scope.usuario);
		expect($scope.mensajes.mensajeOk).toBe("Usuario logado");
		expect(wsnWebInterfaceDataFactory.getUsuarioLogado()).toBe($scope.usuario);
	  }));
	  
	  it('login error', inject(function(wsnWebInterfaceDataFactory) {
	    expect(controller).toBeDefined();
		expect(wsnWebInterfaceDataFactory);
		expect(wsnWebInterfaceDataFactory.getUsuarioLogado()).toBeUndefined();
		expect($scope.logado).toBe(false);
		expect($scope.mensaje_cabecera).toBe('Página de login');

		$scope.usuario = "4444";
		$scope.password = "4444";
		$httpBackend.expectPOST(baseURL + 'login', {"usuario":$scope.usuario, "password":$scope.password}).respond(500, {});
		$scope.login();
		$httpBackend.flush();

		expect($scope.logado).toBe(false);
		expect($scope.mensaje_cabecera).toBe('Página de login');
		expect($scope.mensajes.mensajeError).toBe('Error de conexión');
		expect(wsnWebInterfaceDataFactory.getUsuarioLogado()).toBeUndefined();
	  }));

	  it('logout', inject(function(wsnWebInterfaceDataFactory) {
		expect(controller).toBeDefined();
		expect(wsnWebInterfaceDataFactory);
		expect(wsnWebInterfaceDataFactory.getUsuarioLogado()).toBeUndefined();
		expect($scope.logado).toBe(false);
		expect($scope.mensaje_cabecera).toBe('Página de login');
		
		$scope.usuario = "4444";
		$scope.password = "4444";
		$httpBackend.expectPOST(baseURL + 'login', {"usuario":$scope.usuario, "password":$scope.password}).respond(200, {});
		$scope.login();
		$httpBackend.flush();
		
	    expect($scope.logado).toBe(true);
		expect($scope.mensaje_cabecera).toBe('Ya esta logado como '+$scope.usuario);
		expect($scope.mensajes.mensajeOk).toBe("Usuario logado");
		expect(wsnWebInterfaceDataFactory.getUsuarioLogado()).toBe($scope.usuario);
		
		$httpBackend.expectDELETE(baseURL + 'login').respond(200, {});
		$scope.logout();
		$httpBackend.flush();

		expect(wsnWebInterfaceDataFactory.getUsuarioLogado()).toBeNull();
		expect($scope.logado).toBe(false);
		expect($scope.mensaje_cabecera).toBe('Página de login');
	  }));
	  
	  it('logout error', inject(function(wsnWebInterfaceDataFactory) {
		expect(controller).toBeDefined();
		expect(wsnWebInterfaceDataFactory);
		expect(wsnWebInterfaceDataFactory.getUsuarioLogado()).toBeUndefined();
		expect($scope.logado).toBe(false);
		expect($scope.mensaje_cabecera).toBe('Página de login');
		
		$scope.usuario = "4444";
		$scope.password = "4444";
		$httpBackend.expectPOST(baseURL + 'login', {"usuario":$scope.usuario, "password":$scope.password}).respond(200, {});
		$scope.login();
		$httpBackend.flush();
		
	    expect($scope.logado).toBe(true);
		expect($scope.mensaje_cabecera).toBe('Ya esta logado como '+$scope.usuario);
		expect($scope.mensajes.mensajeOk).toBe("Usuario logado");
		expect(wsnWebInterfaceDataFactory.getUsuarioLogado()).toBe($scope.usuario);
		
		$httpBackend.expectDELETE(baseURL + 'login').respond(500, {});
		$scope.logout();
		$httpBackend.flush();

		expect($scope.logado).toBe(true);
		expect($scope.mensaje_cabecera).toBe('Ya esta logado como '+$scope.usuario);
		expect($scope.mensajes.mensajeOk).toBeNull();
		expect($scope.mensajes.mensajeError).toBe('Error de conexión');
	  }));
	});
	
	describe('ModalControler', function() {

	  var controller, $scope, $filter;
	  var $uibModalInstance = {
		obj:undefined,
		close: function(o) { this.obj = o },
		dismiss: function(o) { this.obj = o },
	  };
	  

	  beforeEach(inject(function(_$controller_, $rootScope, _$filter_){
		$scope = $rootScope.$new();
		$filter = _$filter_;
		var datos = { ordenacion: getOrdenacion(), paginacion: getPaginacion(5), motas:[1,2,3,4,5,6,7,8,9] };
		controller = _$controller_('ModalControler', { '$scope': $scope, '$uibModalInstance':$uibModalInstance, 'datos':datos, '$filter':$filter });
	  }));
	  
	  it('init', inject(function() {
		expect(controller).toBeDefined();
		expect($scope.datos.paginacion.desde).toBe(0);
		expect($scope.datos.paginacion.pagActual).toBe(1);
		expect($scope.datos.paginacion.totalRegistros).toBe(9);
	  }));
	
	  it('ordenar', inject(function() {
		expect(controller).toBeDefined();
		expect($scope.datos.ordenacion.columnaOrden).toBeNull();
		expect($scope.datos.ordenacion.sentido).toBeNull();
		expect($scope.datos.ordenacion.ordenacion).toBeNull();
		
		var col = 'col1';
		$scope.ordenar(col);
		expect($scope.datos.ordenacion.columnaOrden).toBe(col);
	    expect($scope.datos.ordenacion.sentido).toBe(true);
		expect($scope.datos.ordenacion.ordenacion).toBe('+'+col);
		
		$scope.ordenar(col);
		expect($scope.datos.ordenacion.columnaOrden).toBe(col);
	    expect($scope.datos.ordenacion.sentido).toBe(false);
		expect($scope.datos.ordenacion.ordenacion).toBe('-'+col);
		
		col = 'col2';
		$scope.ordenar(col);
		expect($scope.datos.ordenacion.columnaOrden).toBe(col);
	    expect($scope.datos.ordenacion.sentido).toBe(true);
		expect($scope.datos.ordenacion.ordenacion).toBe('+'+col);
	  }));
	  
	  it('iconoOrdenacion', inject(function() {
		expect(controller).toBeDefined();
		expect($scope.datos.ordenacion.columnaOrden).toBeNull();
		expect($scope.datos.ordenacion.sentido).toBeNull();
		expect($scope.datos.ordenacion.ordenacion).toBeNull();
		
		var col = 'col1';
		var s = $scope.iconoOrdenacion(col);
		expect(s).toBe('glyphicon glyphicon-sort');
		
		$scope.ordenar(col);
		s = $scope.iconoOrdenacion(col);
		expect(s).toBe('glyphicon glyphicon-triangle-top');
		
		$scope.ordenar(col);
		s = $scope.iconoOrdenacion(col);
		expect(s).toBe('glyphicon glyphicon-triangle-bottom');
		
		$scope.ordenar('col2');
		s = $scope.iconoOrdenacion(col);
		expect(s).toBe('glyphicon glyphicon-sort');
	  }));
	  
	  it('cancel', inject(function() {
		expect(controller).toBeDefined();
		$scope.cancel();
		expect($uibModalInstance.obj).toBe('cancel');
	  }));
	  
	  it('aceptar', inject(function() {
		expect(controller).toBeDefined();
		$scope.aceptar();
		expect($uibModalInstance.obj).toBe('ok');
	  }));
	  
	  it('aceptar', inject(function() {
		expect(controller).toBeDefined();
		var o = {'1':1};
		$scope.seleccionar(o);
		expect($uibModalInstance.obj).toBe(o);
	  }));

	  it('setPagina', inject(function() {
		expect(controller).toBeDefined();
		expect($scope.datos.paginacion.desde).toBe(0);
		expect($scope.datos.paginacion.pagActual).toBe(1);
		expect($scope.datos.paginacion.totalRegistros).toBe(9);
		
		$scope.setPagina();
		expect($scope.datos.paginacion.desde).toBe(0);
		
		$scope.datos.paginacion.pagActual = 2;
		$scope.setPagina();
		expect($scope.datos.paginacion.desde).toBe(5);
		
		$scope.datos.paginacion.pagActual = 3;
		$scope.setPagina();
		expect($scope.datos.paginacion.desde).toBe(10);
	  }));
	});
});