describe('Controllers Con', function() {
	beforeEach(module('WSNWebInterface'));
	
	beforeEach(inject(function($httpBackend, baseURL){
		$httpBackend.expectGET(baseURL + 'login').respond(200, {});
		$httpBackend.flush();
	}));
	 
	describe('ConsultaController', function() {

	  var controller, $scope, wsnWebInterfaceFactory, $filter, regXPagina = 5, $httpBackend, baseURL;
	  var $uibModal = {open: function() { return {opened: {then: function (f){f();}}, close: function() {}}}};

	  beforeEach(inject(function(_$controller_, $rootScope, _$httpBackend_, _$filter_, _wsnWebInterfaceFactory_, _baseURL_){
		$scope = $rootScope.$new();
		$filter = _$filter_;
		$httpBackend = _$httpBackend_;
		wsnWebInterfaceFactory = _wsnWebInterfaceFactory_;
		baseURL = _baseURL_;
	
		controller = _$controller_('ConsultaController', { '$scope': $scope, '$filter':$filter, '$uibModal':$uibModal, 'wsnWebInterfaceFactory':wsnWebInterfaceFactory, 'regXPagina':regXPagina });	
	  }));
	  
	  it('init', inject(function() {
		$httpBackend.expectGET(baseURL + 'motas').respond(200, [1,2,3,4,5,6,7,8,9]);
	    $httpBackend.flush();
		
		expect(controller).toBeDefined();
		expect(wsnWebInterfaceFactory);
		expect($scope.motas).toBeDefined();
		expect($scope.motas.length).toBe(9);
		expect($scope.motas[0]).toBe(1);
		expect($scope.motas[8]).toBe(9);
		expect($scope.paginacion.desde).toBe(0);
		expect($scope.paginacion.pagActual).toBe(1);
		expect($scope.paginacion.totalRegistros).toBe(9);
		expect($scope.ordenacion.columnaOrden).toBeNull();
		expect($scope.ordenacion.sentido).toBeNull();
		expect($scope.ordenacion.ordenacion).toBeNull();
		expect($scope.mota_seleccionada).toBeUndefined();
		expect($scope.buscador).toBe('');
		expect($scope.mensajes.mensajeError).toBeNull();
	  }));
	  
	  it('init error', inject(function() {
		$httpBackend.expectGET(baseURL + 'motas').respond(500, []);
	    $httpBackend.flush();
		
		expect(controller).toBeDefined();
		expect(wsnWebInterfaceFactory);
		expect($scope.motas).toBeDefined();
		expect($scope.motas.length).toBe(0);
		expect($scope.paginacion.desde).toBe(0);
		expect($scope.paginacion.pagActual).toBe(1);
		expect($scope.paginacion.totalRegistros).toBe(0);
		expect($scope.ordenacion.columnaOrden).toBeNull();
		expect($scope.ordenacion.sentido).toBeNull();
		expect($scope.ordenacion.ordenacion).toBeNull();
		expect($scope.mota_seleccionada).toBeUndefined();
		expect($scope.buscador).toBe('');
		expect($scope.mensajes.mensajeError).toBe('Error de conexión');
	  }));

	  it('ordenar', inject(function() {
		expect(controller).toBeDefined();
		expect($scope.ordenacion.columnaOrden).toBeNull();
		expect($scope.ordenacion.sentido).toBeNull();
		expect($scope.ordenacion.ordenacion).toBeNull();
		
		var col = 'col1';
		$scope.ordenar(col);
		expect($scope.ordenacion.columnaOrden).toBe(col);
	    expect($scope.ordenacion.sentido).toBe(true);
		expect($scope.ordenacion.ordenacion).toBe('+'+col);
		
		$scope.ordenar(col);
		expect($scope.ordenacion.columnaOrden).toBe(col);
	    expect($scope.ordenacion.sentido).toBe(false);
		expect($scope.ordenacion.ordenacion).toBe('-'+col);
		
		col = 'col2';
		$scope.ordenar(col);
		expect($scope.ordenacion.columnaOrden).toBe(col);
	    expect($scope.ordenacion.sentido).toBe(true);
		expect($scope.ordenacion.ordenacion).toBe('+'+col);
	  }));
	  
	  it('iconoOrdenacion', inject(function() {
		expect(controller).toBeDefined();
		expect($scope.ordenacion.columnaOrden).toBeNull();
		expect($scope.ordenacion.sentido).toBeNull();
		expect($scope.ordenacion.ordenacion).toBeNull();
		
		var col = 'col1';
		var s = $scope.iconoOrdenacion(col);
		expect(s).toBe('glyphicon glyphicon-sort');
		
		$scope.ordenar(col);
		s = $scope.iconoOrdenacion(col);
		expect(s).toBe('glyphicon glyphicon-triangle-top');
		
		$scope.ordenar(col);
		s = $scope.iconoOrdenacion(col);
		expect(s).toBe('glyphicon glyphicon-triangle-bottom');
		
		$scope.ordenar('col2');
		s = $scope.iconoOrdenacion(col);
		expect(s).toBe('glyphicon glyphicon-sort');
	  }));
	  
	  it('setPagina', inject(function() {
		$httpBackend.expectGET(baseURL + 'motas').respond(200, [1,2,3,4,5,6,7,8,9]);
	    $httpBackend.flush();
		
		expect(controller).toBeDefined();
		expect($scope.paginacion.desde).toBe(0);
		expect($scope.paginacion.pagActual).toBe(1);
		expect($scope.paginacion.totalRegistros).toBe(9);
		
		$scope.setPagina();
		expect($scope.paginacion.desde).toBe(0);
		
		$scope.paginacion.pagActual = 2;
		$scope.setPagina();
		expect($scope.paginacion.desde).toBe(5);
		
		$scope.paginacion.pagActual = 3;
		$scope.setPagina();
		expect($scope.paginacion.desde).toBe(10);
	  }));
	  
	  it('preparaPaginacion', inject(function() {
		$httpBackend.expectGET(baseURL + 'motas').respond(200, [1,2,3,4,5,6,7,8,9]);
	    $httpBackend.flush();
		
		expect(controller).toBeDefined();
		expect($scope.paginacion.desde).toBe(0);
		expect($scope.paginacion.pagActual).toBe(1);
		expect($scope.paginacion.totalRegistros).toBe(9);
		
		$scope.preparaPaginacion();
		expect($scope.paginacion.desde).toBe(0);
		expect($scope.paginacion.pagActual).toBe(1);
		expect($scope.paginacion.totalRegistros).toBe(9);
		
		$scope.buscador='1';
		$scope.preparaPaginacion();
		expect($scope.paginacion.desde).toBe(0);
		expect($scope.paginacion.pagActual).toBe(1);
		expect($scope.paginacion.totalRegistros).toBe(1);
	  }));
	  
	  it('seleccionarMota', inject(function() {
		$httpBackend.expectGET(baseURL + 'motas').respond(200, [1,2,3,4,5,6,7,8,9]);
	    $httpBackend.flush();
		
		$httpBackend.expectGET(baseURL + 'motas/1/valores').respond(200, [11,22,33,44]);
		$scope.seleccionarMota({id:1});
		$httpBackend.flush();
		
		expect($scope.mota_seleccionada.ordenacion.columnaOrden).toBeNull();
		expect($scope.mota_seleccionada.ordenacion.sentido).toBeNull();
		expect($scope.mota_seleccionada.ordenacion.ordenacion).toBeNull();
		expect($scope.mota_seleccionada.mota).toBeDefined();
		expect($scope.mota_seleccionada.mota.id).toBe(1);
		expect($scope.mota_seleccionada.sensores).toBeDefined();
		expect($scope.mota_seleccionada.sensores.length).toBe(4);
		expect($scope.mota_seleccionada.sensores[0]).toBe(11);
		expect($scope.mota_seleccionada.sensores[3]).toBe(44);
		expect($scope.mensajes.mensajeError).toBeNull();
	  }));
	  
	  it('seleccionarMota error', inject(function() {
		$httpBackend.expectGET(baseURL + 'motas').respond(200, [1,2,3,4,5,6,7,8,9]);
	    $httpBackend.flush();
		
		$httpBackend.expectGET(baseURL + 'motas/1/valores').respond(500, []);
		$scope.seleccionarMota({id:1});
		$httpBackend.flush();
		
		expect($scope.mota_seleccionada.ordenacion.columnaOrden).toBeNull();
		expect($scope.mota_seleccionada.ordenacion.sentido).toBeNull();
		expect($scope.mota_seleccionada.ordenacion.ordenacion).toBeNull();
		expect($scope.mota_seleccionada.mota).toBeDefined();
		expect($scope.mota_seleccionada.mota.id).toBe(1);
		expect($scope.mota_seleccionada.sensores).toBeUndefined();
		expect($scope.mensajes.mensajeError).toBe('Error de conexión');
	  }));
	});

	describe('MapaController', function() {
	  var controller, $scope, wsnWebInterfaceFactory, $filter, $httpBackend, baseURL;
	  var $uibModal = {open: function() { return {opened: {then: function (f){f();}}, close: function() {}}}};
	  var datos = [{X:1,Y:1,desc:'desc1'},{X:2,Y:2,desc:'desc2'},{X:3,Y:3,desc:'desc3'},{X:4,Y:4,desc:'desc4'},{X:5,Y:5,desc:'desc5'}];

	  beforeEach(inject(function(_$controller_, $rootScope, _$httpBackend_, _$filter_, _wsnWebInterfaceFactory_, _baseURL_){
		$scope = $rootScope.$new();
		$filter = _$filter_;
		$httpBackend = _$httpBackend_;
		wsnWebInterfaceFactory = _wsnWebInterfaceFactory_;
		baseURL = _baseURL_;

		controller = _$controller_('MapaController', { '$scope': $scope, '$filter':$filter, '$uibModal':$uibModal, 'wsnWebInterfaceFactory':wsnWebInterfaceFactory });	
	  }));
	  
	  it('init', inject(function() {
		$httpBackend.expectGET(baseURL + 'motas').respond(200, datos);
		$httpBackend.expectGET(baseURL + 'mapa/info').respond(200, [{X:1, Y:1}]);
	    $httpBackend.flush();
		
		expect(controller).toBeDefined();
		expect(wsnWebInterfaceFactory);
		expect($scope.motas).toBeDefined();
		expect($scope.motas.length).toBe(5);
		expect($scope.motas[0].X).toBe(1);
		expect($scope.motas[4].X).toBe(5);
		expect($scope.mota_seleccionada).toBeUndefined();
		expect($scope.mensajes.mensajeError).toBeNull();
	  }));
	  
	  it('init error', inject(function() {
		$httpBackend.expectGET(baseURL + 'motas').respond(500, []);
	    $httpBackend.flush();
		
		expect(controller).toBeDefined();
		expect(wsnWebInterfaceFactory);
		expect($scope.motas).toBeDefined();
		expect($scope.motas.length).toBe(0);
		expect($scope.mota_seleccionada).toBeUndefined();
		expect($scope.mensajes.mensajeError).toBe('Error de conexión');
	  }));
	  
	  it('init error 2', inject(function() {
		$httpBackend.expectGET(baseURL + 'motas').respond(200, datos);
		$httpBackend.expectGET(baseURL + 'mapa/info').respond(500, {});
	    $httpBackend.flush();
		
		expect(controller).toBeDefined();
		expect(wsnWebInterfaceFactory);
		expect($scope.motas).toBeDefined();
		expect($scope.motas.length).toBe(0);
		expect($scope.mota_seleccionada).toBeUndefined();
		expect($scope.mensajes.mensajeError).toBe('Error de conexión');
	  }));
	  
	  it('onClickMapa', inject(function() {
		$httpBackend.expectGET(baseURL + 'motas').respond(200, datos);
		$httpBackend.expectGET(baseURL + 'mapa/info').respond(200, [{X:1, Y:1}]);
	    $httpBackend.flush();
		
		expect(controller).toBeDefined();
		expect(wsnWebInterfaceFactory);
		expect($scope.motas).toBeDefined();
		expect($scope.motas.length).toBe(5);
		expect($scope.motas[0].X).toBe(1);
		expect($scope.motas[4].X).toBe(5);
		expect($scope.mota_seleccionada).toBeUndefined();
		
		$httpBackend.expectGET(baseURL + 'motas/1/valores').respond(200, [11,22,33,44]);
	    var mota = {id:1};
		$scope.onClickMapa(mota);
		$httpBackend.flush();
		
		expect($scope.mota_seleccionada).toBeDefined();
		expect($scope.mota_seleccionada.ordenacion).toBeDefined();
		expect($scope.mota_seleccionada.mota).toBeDefined();
		expect($scope.mota_seleccionada.mota).toBe(mota);
		expect($scope.mota_seleccionada.ordenacion.columnaOrden).toBeNull();
		expect($scope.mota_seleccionada.ordenacion.sentido).toBeNull();
		expect($scope.mota_seleccionada.ordenacion.ordenacion).toBeNull();
		expect($scope.mota_seleccionada.sensores).toBeDefined();
		expect($scope.mota_seleccionada.sensores.length).toBe(4);
		expect($scope.mota_seleccionada.sensores[0]).toBe(11);
		expect($scope.mota_seleccionada.sensores[3]).toBe(44);
		expect($scope.mensajes.mensajeError).toBeNull();
	  }));
	  
	  it('onClickMapa error', inject(function() {
		$httpBackend.expectGET(baseURL + 'motas').respond(200, datos);
		$httpBackend.expectGET(baseURL + 'mapa/info').respond(200, [{X:1, Y:1}]);
	    $httpBackend.flush();
		
		expect(controller).toBeDefined();
		expect(wsnWebInterfaceFactory);
		expect($scope.motas).toBeDefined();
		expect($scope.motas.length).toBe(5);
		expect($scope.motas[0].X).toBe(1);
		expect($scope.motas[4].X).toBe(5);
		expect($scope.mota_seleccionada).toBeUndefined();
		
		$httpBackend.expectGET(baseURL + 'motas/1/valores').respond(500, []);
	    var mota = {id:1};
		$scope.onClickMapa(mota);
		$httpBackend.flush();
		
		expect($scope.mota_seleccionada).toBeDefined();
		expect($scope.mota_seleccionada.ordenacion).toBeDefined();
		expect($scope.mota_seleccionada.mota).toBeDefined();
		expect($scope.mota_seleccionada.mota).toBe(mota);
		expect($scope.mota_seleccionada.ordenacion.columnaOrden).toBeNull();
		expect($scope.mota_seleccionada.ordenacion.sentido).toBeNull();
		expect($scope.mota_seleccionada.ordenacion.ordenacion).toBeNull();
		expect($scope.mota_seleccionada.sensores).toBeUndefined();
		expect($scope.mensajes.mensajeError).toBe('Error de conexión');
	  }));
	  
	   it('descargarImagen', inject(function() {
	    $httpBackend.expectGET(baseURL + 'motas').respond(200, datos);
		$httpBackend.expectGET(baseURL + 'mapa/info').respond(200, [{X:1, Y:1}]);
	    $httpBackend.flush();

		expect(controller).toBeDefined();
		expect(wsnWebInterfaceFactory);
		expect($scope.motas).toBeDefined();
		expect($scope.motas.length).toBe(5);
		expect($scope.motas[0].X).toBe(1);
		expect($scope.motas[4].X).toBe(5);
		expect($scope.mota_seleccionada).toBeUndefined();
		
		$scope.descargarImagen();
	   }));
	});

	describe('HistoricoController', function() {

	  var controller, $scope, wsnWebInterfaceFactory, $filter, regXPagina = 5, $httpBackend, baseURL;
	  var $uibModal = {open: function() { return {opened: {then: function (f){f();}}, close: function() {}, result:{then: function(callback){ callback({id:1}); }}} } };
	  var datos = [{X:1,Y:1,desc:'desc1'},{X:2,Y:2,desc:'desc2'},{X:3,Y:3,desc:'desc3'},{X:4,Y:4,desc:'desc4'},{X:5,Y:5,desc:'desc5'}];
	  
	  beforeEach(inject(function(_$controller_, $rootScope, _$httpBackend_, _$filter_, _wsnWebInterfaceFactory_, _baseURL_){
		$scope = $rootScope.$new();
		$filter = _$filter_;
		$httpBackend = _$httpBackend_;
		wsnWebInterfaceFactory = _wsnWebInterfaceFactory_;
		baseURL = _baseURL_;
	
		controller = _$controller_('HistoricoController', { '$scope': $scope, '$filter':$filter, '$uibModal':$uibModal, 'wsnWebInterfaceFactory':wsnWebInterfaceFactory, 'regXPagina':regXPagina });	
	  }));
	  
	  it('init', inject(function() {
		$httpBackend.expectGET(baseURL + 'motas').respond(200, datos);
	    $httpBackend.flush();
	
		expect(controller).toBeDefined();
		expect(wsnWebInterfaceFactory);
		expect($scope.motas).toBeDefined();
		expect($scope.motas.length).toBe(5);
		expect($scope.motas[0].X).toBe(1);
		expect($scope.motas[4].X).toBe(5);
		expect($scope.mensajes.mensajeError).toBeNull();
	  }));
	  
	  it('init error', inject(function() {
		$httpBackend.expectGET(baseURL + 'motas').respond(500, []);
	    $httpBackend.flush();
		
		expect(controller).toBeDefined();
		expect(wsnWebInterfaceFactory);
		expect($scope.motas).toBeDefined();
		expect($scope.motas.length).toBe(0);
		expect($scope.mensajes.mensajeError).toBe('Error de conexión');
	  }));
	  
	  it('seleccionarMota', inject(function() {
	    $httpBackend.expectGET(baseURL + 'motas').respond(200, datos);
	    $httpBackend.flush();
	
		expect(controller).toBeDefined();
		expect(wsnWebInterfaceFactory);
		expect($scope.motaSeleccionada).toBeUndefined();
		
		$scope.seleccionarMota();
		expect($scope.motaSeleccionada).toBeDefined();
		expect($scope.motaSeleccionada.id).toBe(1);
	  }));
	  

	  it('seleccionarSensor', inject(function() {
	    $httpBackend.expectGET(baseURL + 'motas').respond(200, datos);
	    $httpBackend.flush();
		
		expect(controller).toBeDefined();
		expect(wsnWebInterfaceFactory);
		expect($scope.sensores).toBeDefined();
		expect($scope.sensores.length).toBe(0);

		$scope.motaSeleccionada = {id:1};
		$httpBackend.expectGET(baseURL + 'motas/1/valores').respond(200, [11,22,33,44]);
		$scope.seleccionarSensor();
	    $httpBackend.flush();
		
		expect($scope.sensores).toBeDefined();
		expect($scope.sensores.length).toBe(4);
		expect($scope.sensores[0]).toBe(11);
		expect($scope.sensores[3]).toBe(44);
		expect($scope.mensajes.mensajeError).toBeNull();
	  }));
	  
	  it('seleccionarSensor error', inject(function() {
	    $httpBackend.expectGET(baseURL + 'motas').respond(200, datos);
	    $httpBackend.flush();
		
		expect(controller).toBeDefined();
		expect(wsnWebInterfaceFactory);
		expect($scope.sensores).toBeDefined();
		expect($scope.sensores.length).toBe(0);

		$scope.motaSeleccionada = {id:1};
		$httpBackend.expectGET(baseURL + 'motas/1/valores').respond(500, []);
		$scope.seleccionarSensor();
	    $httpBackend.flush();
		
		expect($scope.sensores).toBeDefined();
		expect($scope.sensores.length).toBe(0);
		expect($scope.mensajes.mensajeError).toBe('Error de conexión');
	  }));
	  
	  it('seleccionarValores', inject(function() {
	    $httpBackend.expectGET(baseURL + 'motas').respond(200, datos);
	    $httpBackend.flush();
		
		expect(controller).toBeDefined();
		expect(wsnWebInterfaceFactory);
		expect($scope.valores).toBeDefined();
		expect($scope.valores.length).toBe(0);
		
		$scope.motaSeleccionada = {id:1};
		$scope.sensorSeleccionado = {id:1};

		$httpBackend.expectGET(baseURL + 'motas/1/valores/1/15').respond(200, [111,222,333,444,555]);
		$scope.seleccionarValores();
		$httpBackend.flush();
		
		expect($scope.valores).toBeDefined();
		expect($scope.valores.length).toBe(5);
		expect($scope.valores[0]).toBe(111);
		expect($scope.valores[4]).toBe(555);
		expect($scope.mensajes.mensajeError).toBeNull();
	  }));

	  it('seleccionarValores error', inject(function() {
	    $httpBackend.expectGET(baseURL + 'motas').respond(200, datos);
	    $httpBackend.flush();
		
		expect(controller).toBeDefined();
		expect(wsnWebInterfaceFactory);
		expect($scope.valores).toBeDefined();
		expect($scope.valores.length).toBe(0);
		
		$scope.motaSeleccionada = {id:1};
		$scope.sensorSeleccionado = {id:1};

		$httpBackend.expectGET(baseURL + 'motas/1/valores/1/15').respond(500, []);
		$scope.seleccionarValores();
		$httpBackend.flush();
		
		expect($scope.valores).toBeDefined();
		expect($scope.valores.length).toBe(0);
		expect($scope.mensajes.mensajeError).toBe('Error de conexión');
	  }));
	});
});