describe('Filtros y directivas', function() {
  beforeEach(module('WSNWebInterface'));
  
  beforeEach(inject(function($httpBackend, baseURL){
		$httpBackend.expectGET(baseURL + 'login').respond(200, {});
		$httpBackend.flush();
  }));
  
  describe('Filtros', function() {
    var $filter;
	
    beforeEach(inject(function(_$filter_){
		$filter = _$filter_;
	}));
  
    it('startFrom', function () {
      var resultado = $filter('startFrom')([1,2,3,4,5], 1);

      expect(resultado).toEqual([2,3,4,5]);
	  
	  resultado = $filter('startFrom')([1,2,3,4,5], 3);

      expect(resultado).toEqual([4,5]);
    });
	
	it('fmtFecha', function () {
      var resultado = $filter('fmtFecha')('2016-04-12 13:58:43');
      expect(resultado).toEqual('12/04/2016 13:58:43');
	  
      resultado = $filter('fmtFecha')(null);

      expect(resultado).toBeNull();
    });
  });
  
  describe('Directivas', function() {
    var $compile, $scope;
	
    beforeEach(inject(function(_$compile_,$rootScope){
	  $compile = _$compile_;
	  $scope = $rootScope.$new();
	}));

    describe('integer', function() {
	  var formulario;
	  
	  beforeEach(inject(function(){
		var element = angular.element(
			  '<form name="form">' +
			  '<input ng-model="dato" name="dato" integer />' +
			  '</form>'
			);
		$scope.dato = null;
		$compile(element)($scope);
		formulario = $scope.form;
	  }));

      it('ok', function() {
        formulario.dato.$setViewValue('3');
        $scope.$digest();
        expect($scope.dato).toEqual('3');
        expect(formulario.dato.$valid).toBe(true);
      });
      
	  it('error', function() {
        formulario.dato.$setViewValue('1a');
        $scope.$digest();
        expect($scope.dato).toBeUndefined();
        expect(formulario.dato.$valid).toBe(false);
      });
	});
	
	describe('validaciongenerica', function() {
	  describe('validaciongenerica entero', function() {
	    var formulario;
	    
	    beforeEach(inject(function(){
		  var element = angular.element(
		  	  '<form name="form">' +
		  	  '<input ng-model="dato" name="dato" validaciongenerica data-tipo="1" data-maxlen="4"/>' +
		  	  '</form>'
		  	);
		  $scope.dato = null;
		  $compile(element)($scope);
		  formulario = $scope.form;
	    }));
        
        it('ok', function() {
          formulario.dato.$setViewValue('3');
          $scope.$digest();
          expect($scope.dato).toEqual('3');
          expect(formulario.dato.$valid).toBe(true);
        });
        
	    it('error', function() {
          formulario.dato.$setViewValue('1a');
          $scope.$digest();
          expect($scope.dato).toBeUndefined();
          expect(formulario.dato.$valid).toBe(false);
        });
		
		it('error len', function() {
          formulario.dato.$setViewValue('11111');
          $scope.$digest();
          expect($scope.dato).toBeUndefined();
          expect(formulario.dato.$valid).toBe(false);
        });
	  });
	  
	  describe('validaciongenerica string', function() {
	    var formulario;
	    
	    beforeEach(inject(function(){
		  var element = angular.element(
		  	  '<form name="form">' +
		  	  '<input ng-model="dato" name="dato" validaciongenerica data-tipo="2" data-maxlen="4"/>' +
		  	  '</form>'
		  	);
		  $scope.dato = null;
		  $compile(element)($scope);
		  formulario = $scope.form;
	    }));
        
        it('ok', function() {
          formulario.dato.$setViewValue('3');
          $scope.$digest();
          expect($scope.dato).toEqual('3');
          expect(formulario.dato.$valid).toBe(true);
        });
		
		it('error len', function() {
          formulario.dato.$setViewValue('11111');
          $scope.$digest();
          expect($scope.dato).toBeUndefined();
          expect(formulario.dato.$valid).toBe(false);
        });
	  });
	  
	  describe('validaciongenerica ipv6s', function() {
	    var formulario;
	    
	    beforeEach(inject(function(){
		  var element = angular.element(
		  	  '<form name="form">' +
		  	  '<input ng-model="dato" name="dato" validaciongenerica data-tipo="3" data-maxlen="50"/>' +
		  	  '</form>'
		  	);
		  $scope.dato = null;
		  $compile(element)($scope);
		  formulario = $scope.form;
	    }));
        
        it('ok', function() {
          formulario.dato.$setViewValue('[::1]:1');
          $scope.$digest();
          expect($scope.dato).toEqual('[::1]:1');
          expect(formulario.dato.$valid).toBe(true);
		  
		  formulario.dato.$setViewValue('[1::1]:1');
          $scope.$digest();
          expect($scope.dato).toEqual('[1::1]:1');
          expect(formulario.dato.$valid).toBe(true);
		  
		  formulario.dato.$setViewValue('[1:1::1]:1');
          $scope.$digest();
          expect($scope.dato).toEqual('[1:1::1]:1');
          expect(formulario.dato.$valid).toBe(true);
        });
		
		it('ok 2', function() {
          formulario.dato.$setViewValue('[::1]:1,[::1]:1');
          $scope.$digest();
          expect($scope.dato).toEqual('[::1]:1,[::1]:1');
          expect(formulario.dato.$valid).toBe(true);
		  
		  formulario.dato.$setViewValue('[1::1]:1,[1::1]:1');
          $scope.$digest();
          expect($scope.dato).toEqual('[1::1]:1,[1::1]:1');
          expect(formulario.dato.$valid).toBe(true);
		  
		  formulario.dato.$setViewValue('[1:1::1]:1,[1:1::1]:1');
          $scope.$digest();
          expect($scope.dato).toEqual('[1:1::1]:1,[1:1::1]:1');
          expect(formulario.dato.$valid).toBe(true);
        });
		
		it('error', function() {
          formulario.dato.$setViewValue('11111');
          $scope.$digest();
          expect($scope.dato).toBeUndefined();
          expect(formulario.dato.$valid).toBe(false);
		  
		  formulario.dato.$setViewValue('[1:1]:1');
          $scope.$digest();
          expect($scope.dato).toBeUndefined();
          expect(formulario.dato.$valid).toBe(false);
		  
		  formulario.dato.$setViewValue('[1:1::1]:1,[1:1]:1');
          $scope.$digest();
          expect($scope.dato).toBeUndefined();
          expect(formulario.dato.$valid).toBe(false);
		  
		  formulario.dato.$setViewValue('[1:1::1]:1,');
          $scope.$digest();
          expect($scope.dato).toBeUndefined();
          expect(formulario.dato.$valid).toBe(false);
        });
		
		it('error len', function() {
		  formulario.dato.$setViewValue('[1:1::1]:1,[1:1::1]:1,[1:1::1]:1,[1:1::1]:1,[1:1::1]:1,[1:1::1]:1');
          $scope.$digest();
          expect($scope.dato).toBeUndefined();
          expect(formulario.dato.$valid).toBe(false);
        });
	  });
      
      describe('validaciongenerica ids', function() {
	    var formulario;
	    
	    beforeEach(inject(function(){
		  var element = angular.element(
		  	  '<form name="form">' +
		  	  '<input ng-model="dato" name="dato" validaciongenerica data-tipo="4" data-maxlen="10"/>' +
		  	  '</form>'
		  	);
		  $scope.dato = null;
		  $compile(element)($scope);
		  formulario = $scope.form;
	    }));
        
        it('ok', function() {
          formulario.dato.$setViewValue('1');
          $scope.$digest();
          expect($scope.dato).toEqual('1');
          expect(formulario.dato.$valid).toBe(true);
		  
		  formulario.dato.$setViewValue('1,2');
          $scope.$digest();
          expect($scope.dato).toEqual('1,2');
          expect(formulario.dato.$valid).toBe(true);
		  
		  formulario.dato.$setViewValue('1,2,3');
          $scope.$digest();
          expect($scope.dato).toEqual('1,2,3');
          expect(formulario.dato.$valid).toBe(true);
          
          formulario.dato.$setViewValue('T');
          $scope.$digest();
          expect($scope.dato).toEqual('T');
          expect(formulario.dato.$valid).toBe(true);
          
          formulario.dato.$setViewValue('N');
          $scope.$digest();
          expect($scope.dato).toEqual('N');
          expect(formulario.dato.$valid).toBe(true);
        });
		
		it('error', function() {
          formulario.dato.$setViewValue('a');
          $scope.$digest();
          expect($scope.dato).toBeUndefined();
          expect(formulario.dato.$valid).toBe(false);
		  
		  formulario.dato.$setViewValue('1,a');
          $scope.$digest();
          expect($scope.dato).toBeUndefined();
          expect(formulario.dato.$valid).toBe(false);
        });
		
		it('error len', function() {
		  formulario.dato.$setViewValue('1,2,3,4,5,6,7,8,9,10');
          $scope.$digest();
          expect($scope.dato).toBeUndefined();
          expect(formulario.dato.$valid).toBe(false);
        });
	  });
	});
  });
});