"""
Modulo de acceso a datos DAO
La conexion la gestiona la aplicacion web a traves de las facilidades
que proporciona FLASK
"""

import hashlib

def login(db, usuario, password):
    """
    Valida el usuario/password en el login de la aplicacion
    """
    return len(_query_db(db, 'select usuario from USUARIOS where usuario = ? and password = ?', [usuario, hashlib.sha512(password).hexdigest()])) > 0

def sensores(db):
    """
    Listado de sensores
    """
    return _query_db(db, 'select id, descripcion, unidades, conversion from SENSORES order by descripcion asc')

def parametros(db):
    """
    Listado de parametros
    """
    return _query_db(db, """
select P.id, P.descripcion, P.id_tipos_parametro, P.mota, TP.longitud, TP.descripcion
from PARAMETROS P, TIPOS_PARAMETRO TP
where  TP.id = P.id_tipos_parametro
order by P.descripcion asc
    """)

def motasSimple(db):
    """
    Consulta simple de las motas
    """
    return _query_db(db, 'select M.id, M.ip from MOTAS M')

def motaId(db, id):
    """
    Consulta de los datos de una mota
    """
    return _query_db(db, 'select id, ip, fecha from MOTAS where id = ?', [id])

def _motaIp(db, ip):
    """
    Consulta de los datos de una mota
    """
    return _query_db(db, 'select id, ip, fecha from MOTAS where ip = ?', [ip])

def ultimos_valores_motas(db, idMota):
    """
    Consulta los ultimos valores de una mota
    """
    return _query_db(db, """
select V.id_sensor, S.descripcion, V.fecha, V.valor, S.unidades
from VALORES_SENSORES V, SENSORES S
where V.id_mota = ? and S.id = V.id_sensor and V.ultimo=1
order by S.descripcion asc;
    """, [idMota])

def valores_mota_sensor(db, idMota, idSensor, limite):
    """
    Consulta los ultimos valores de una mota y un sensor
    """
    return _query_db(db, """
select V.fecha, V.valor, S.unidades
from VALORES_SENSORES V, SENSORES S
where V.id_mota = ? and V.id_sensor = ? and S.id = V.id_sensor
order by V.fecha asc
LIMIT ?;
    """, [idMota, idSensor,limite])

def motasExtendido(db):
    """
    Consulta extendida de las motas
    """
    return _query_db(db, """
select M.id, M.ip, M.fecha, M.fechaUltimo, M.sinc, M.sincMota, P.interfaz, VP.valor 
from MOTAS M, PARAMETROS P, VALORES_PARAMETROS VP
where M.id=VP.id_mota and P.id=VP.id_parametro and P.interfaz is not null
order by M.fecha asc, M.id
    """)

def motaAlerta(db, idMota):
	"""
	Consulta el mensaje de alerta de la mota
	"""
	datos = _query_db(db, 'select alerta from VALORES_STATUS where id_mota = ? and alerta is not null', [idMota])
	alerta = None
	for dato in datos:
		if alerta != None:
			alerta = alerta + "," + dato[0]
		else:
			alerta = dato[0]
	return alerta
	
def borra_mota(db, idMota):
    """
    Elimina una mota del la bbdd incluidos sus valores
    """
    db.execute('delete from VALORES_SENSORES where id_mota = ? ', [idMota])
    db.execute('delete from VALORES_PARAMETROS where id_mota = ? ', [idMota])
    db.execute('delete from VALORES_STATUS where id_mota = ? ', [idMota])
    db.execute('delete from MOTAS where id = ? ', [idMota])
    db.commit()

def mota_status(db, idMota):
    """
    Consulta los valores de status de una mota
    """
    return _query_db(db, """
select S.id, S.descripcion, S.comparacion, VS.valor, S.valor_critico, VS.fecha, S.unidades
from STATUS S, VALORES_STATUS VS
where VS.id_mota = ? and VS.id_status = S.id
order by S.descripcion asc
    """, [idMota])

def desc_tabla(db, tabla):
    """
    Recupera los metadatos de una tabla
    """
    return _query_db(db, 'PRAGMA table_info('+tabla+')')

def datos_tabla(db, tabla):
    """
    Recupera todos los datos de una tabla
    """
    campo = 'id'
    if tabla == 'usuarios':
        campo = 'usuario'
    return _query_db(db, 'select * from ' + tabla + ' order by ' + campo + ' asc')

def update_datos_tabla(db, tabla, datos):
    """
    Inserta o actualiza los datos de una tabla
    """
    campos = ''
    vals = ''
    valores = []
    for val_id in datos.keys():
        campos += val_id + ','
        vals += '?,'
        valores.append(datos[val_id])
    sql = 'insert or replace into ' + tabla + '(' + campos[:-1] + ') values(' + vals[:-1] + ')'
    db.execute(sql, valores)
    db.commit()

def update_usuario(db, datos):
    """
    Inserta o actualiza en la tabla de usuarios
    """
    sql = 'insert or replace into usuarios (usuario, password) values(?,?)'
    db.execute(sql, [datos['usuario'], hashlib.sha512(datos['password']).hexdigest()])
    db.commit()
    
def delete_datos_tabla(db, tabla, id):
    """
    Borra en la tabla maestra
    """
    campo = 'id'
    if tabla == 'usuarios':
        campo = 'usuario'
    db.execute('delete from ' + tabla + ' where ' + campo + ' = ?', [id])
    db.commit()

def status(db):
    """
    Consulta simple de los parametros de estado
    """
    return _query_db(db, 'select id, valor_critico, comparacion, alerta, conversion from STATUS order by id asc')

def inserta_datos_sensor(db, ip, datos, alarmas):
    """
    Inserta los datos de un sensor para una mota
    """

    id = None
    conId = _motaIp(db, ip)
    if len(conId) > 0:
        id = conId[0][0] 

    if id == None:
        db.execute("insert into MOTAS (ip, fecha) values (?,datetime('now','localtime'))", [ip] )
        myId = _motaIp(db, ip)[0][0]
        #Insertando valores de configuracion por defecto
        parametros = _query_db(db, 'select id,defecto from PARAMETROS')
        for parametro in parametros:
            defecto = parametro[1]
            if defecto == None:
                defecto = ip
            db.execute("insert into VALORES_PARAMETROS (id_mota, id_parametro, fecha, valor) values (?,?,datetime('now','localtime'),?)", [myId, parametro[0], defecto] )
    else:
        myId = id

    if datos.get("s") != None:
        for idSensor in datos["s"]:
            if id != None:
                db.execute("update VALORES_SENSORES set ultimo=0 where ultimo=1 and id_mota=? and id_sensor=?", [myId, idSensor] )
            db.execute("insert into VALORES_SENSORES (id_mota, id_sensor, fecha, valor, ultimo) values(?,?,datetime('now','localtime'),?,1)", [myId, idSensor, datos["s"][idSensor]] )

    if datos.get("e") != None:
        for idEstado in datos["e"]:
            al = alarmas.get(idEstado)
            db.execute("insert or replace into VALORES_STATUS (id_mota, id_status, fecha, valor, alerta) values (?,?,datetime('now','localtime'),?,?)", [myId, idEstado, datos["e"][idEstado], al] )

    if datos.get("f") != None:
        db.execute("update MOTAS set sincMota=?, fechaUltimo=datetime('now','localtime') where id=?", [datos["f"], myId])

    db.commit()

def inserta_valores_parametros(db, idMota, datos, sinc):
    """
    Inserta los valores de parametros de una mota
    """
    for k in datos:
        db.execute("insert or replace into VALORES_PARAMETROS (id_mota, id_parametro, fecha, valor) values (?,?,datetime('now','localtime'),?)", [idMota, k["id"], k["valor"]] )
    if sinc != None:
        db.execute("update MOTAS set sinc=?, sincMota=? where id=?", [sinc, sinc, idMota])
    db.commit()

def valores_parametros(db, idMota):
    """
    Consulta los valores de parametros de una mota
    """
    return _query_db(db, 'select id_parametro, valor, fecha from VALORES_PARAMETROS where id_mota = ? order by id_parametro asc', [idMota])

def get_mapa_info(db):
    """
    Consulta la informacion del mapa
    """
    return _query_db(db, 'select X,Y from MAPA')

def update_mapa(db, X, Y):
    """
    Consulta la informacion del mapa
    """
    db.execute('DELETE from MAPA', [])
    db.execute('INSERT into MAPA(X,Y) VALUES(?,?)', [X,Y])
    db.commit()

def _query_db(db, query, args=(), one=False):
    """
    Funcion de consulta generica
    """
    cur = db.execute(query, args)
    rv = cur.fetchall()
    cur.close()
    return (rv[0] if rv else None) if one else rv
