#include "string.h"
#include "stdio.h"

#define PARAM_SINCRONIZACION 0
#define PARAM_SERVIDORES 1
#define PARAM_PERIODO 2
#define PARAM_SENSORES_ACTIVOS 3

#define TRUE 1
#define FALSE 0

#define COAP_CODE_REQ_GET 1
#define COAP_CODE_REQ_POST 2

#define MAX_SERVIDORES 10
#define MAX_SENSORES 6
#define MAX_ESTADO 2

typedef unsigned char uint8_t;
typedef unsigned int uint16_t;
typedef unsigned long int uint32_t;
typedef long int int32_t;
typedef unsigned char bool;
typedef char int8_t;

typedef void (*_uocapp_trata_sensor)(uint8_t);
typedef void (*_uocapp_trata_direccion_servidor)(uint8_t*, uint16_t, uint8_t);

const uint8_t digitos[] = {'0','1','2','3','4','5','6','7','8','9'};
const uint8_t digitos_hex[] = {'0','1','2','3','4','5','6','7','8','9','A','B','C','D','E','F'};
const uint8_t SENSORES_ACTIVOS[] = {1,2,3,4,5,6};
const uint8_t SENSORES_ACTIVOS_ESTADO[] = {1,2};

typedef struct {
   bool enEjecucion; // indicador de que la tarea esta en ejecucion
   uint32_t periodo; // periodo de la tarea planificada en ms
} uocapp_vars_timer_t;

typedef struct {
  uint8_t id; // id del sensor
  bool activo;
  uint8_t sen;
} uocapp_vars_sensor_t;

typedef struct {
  uint8_t id; // id del sensor
  uint8_t idStatus; // id del parametro de estado
  uint8_t sen;
} uocapp_vars_estado_t;

typedef struct {
  uint16_t puerto;
  uint8_t ipv6Addr[16];
  bool activo;
} uocapp_vars_servidor_t;

typedef struct {
   uocapp_vars_timer_t tarea;

   uocapp_vars_sensor_t sensores[MAX_SENSORES]; // sensores

   uocapp_vars_estado_t estado[MAX_ESTADO]; // sensores para parametros de estado

   uocapp_vars_servidor_t servidores[MAX_SERVIDORES]; // servidores a los que hay que informar la respuesta

   uint32_t sincronizacion; // parametro de sincronizacion con la parte web
} uocapp_vars_t;


void uocapp_init(void);

uocapp_vars_t uocapp_vars;

void uocapp_coap_receive(uint8_t, uint8_t*);

void uocapp_tarea_planificada(void);

void uocapp_modificar_parametros(uint8_t*);

uint32_t uocapp_parsea_peticion(uint8_t*, uint32_t, uint8_t*);

void uocapp_parsea_lista_sensores(uint8_t*, _uocapp_trata_sensor);

void uocapp_parsea_param_servidor(uint8_t*, _uocapp_trata_direccion_servidor);

void uocapp_trata_sensor(uint8_t);

void uocapp_trata_direccion_servidor(uint8_t*, uint16_t, uint8_t);

void uocapp_coap_send(uint8_t*,uint32_t);

void uocapp_modifica_planificacion(uint32_t);

uint32_t uocapp_lectura_sensores(uint8_t*, uint8_t);

uint32_t uocapp_lectura_sensores_estado(uint8_t*);

void uocapp_tarea_planificada_exec(void);

uint32_t uocapp_len(uint8_t*);
uint32_t uocapp_cc_s(uint8_t*, uint32_t, char*, uint8_t);
uint32_t uocapp_cc_sd(uint8_t*, uint32_t, uint8_t);
uint32_t uocapp_cc_d(uint8_t*, uint32_t, uint16_t);
uint32_t uocapp_cc_ld(uint8_t*, uint32_t, uint32_t);
uint32_t uocapp_cc_pv(uint8_t*, uint32_t, uint8_t, uint32_t);
uint32_t uocapp_cc_hex(uint8_t*, uint32_t, uint8_t);
uint32_t uocapp_atoi(uint8_t*, uint8_t);


int SENSOR = 11111;
int STATUS = 22222;

int main(void) {
	uocapp_init();
	uocapp_tarea_planificada();
	uocapp_coap_receive(COAP_CODE_REQ_GET, NULL);
	uocapp_coap_receive(COAP_CODE_REQ_POST, "{\"0\":1,\"2\":50,\"3\":\"N\"}");
	uocapp_coap_receive(COAP_CODE_REQ_POST, "{\"1\":\"0BBBB:1FFFF\"}");
	uocapp_coap_receive(COAP_CODE_REQ_POST, "{\"1\":\"1-\"}");
	uocapp_coap_receive(COAP_CODE_REQ_GET, NULL);
	uocapp_tarea_planificada();
	uocapp_coap_receive(COAP_CODE_REQ_GET, NULL);
	uocapp_coap_receive(COAP_CODE_REQ_POST, "{\"0\":2,\"2\":0,\"3\":\"T\"}");
	uocapp_coap_receive(COAP_CODE_REQ_POST, "{\"1\":\"0BBBB:1FFFF\"}");
	uocapp_coap_receive(COAP_CODE_REQ_POST, "{\"1\":\"1AAAA00:0020001\"}");
	uocapp_coap_receive(COAP_CODE_REQ_POST, "{\"1\":\"2-\"}");
	uocapp_coap_receive(COAP_CODE_REQ_GET, NULL);
	uocapp_tarea_planificada();
	uocapp_coap_receive(COAP_CODE_REQ_GET, NULL);
	uocapp_coap_receive(COAP_CODE_REQ_POST, "{\"0\":3,\"2\":300,\"3\":\"1,3,5\"}");
	uocapp_coap_receive(COAP_CODE_REQ_POST, "{\"1\":\"0BBBB000000:00001FFFF\"}");
	uocapp_coap_receive(COAP_CODE_REQ_POST, "{\"1\":\"1-\"}");
	uocapp_coap_receive(COAP_CODE_REQ_GET, NULL);
	uocapp_tarea_planificada();
	return 0;
}

void uocapp_init() {
   uint8_t iCnt = 0;

   // Inicializando temporizador
   if (!uocapp_vars.tarea.enEjecucion) {
	uocapp_vars.tarea.periodo = 500 * 1000;
	uocapp_vars.tarea.enEjecucion = TRUE;
   }

   // Inicializando la lista de sensores
   for (iCnt = 0; iCnt < MAX_SENSORES; iCnt++) {
		uocapp_vars.sensores[iCnt].id = SENSORES_ACTIVOS[iCnt];
		uocapp_vars.sensores[iCnt].activo = TRUE;
		uocapp_vars.sensores[iCnt].sen = 1;
   }

   // Inicializando la lista de sensores
   for (iCnt = 0; iCnt < MAX_ESTADO; iCnt++) {
   		uocapp_vars.estado[iCnt].id = SENSORES_ACTIVOS_ESTADO[iCnt];
   		uocapp_vars.estado[iCnt].idStatus = iCnt + 1;
   		uocapp_vars.estado[iCnt].sen = 1;
   }

   // Inicializando la lista de servidores destino
   uocapp_vars.servidores[0].puerto = 55555;
   memset(uocapp_vars.servidores[0].ipv6Addr, 0, 16); // localhost [::1]
   uocapp_vars.servidores[0].ipv6Addr[15] = 0x01;
   uocapp_vars.servidores[0].activo = TRUE;

   // Inicializando la sincronizacion
   uocapp_vars.sincronizacion = 0;
}

void uocapp_coap_receive(uint8_t Code, uint8_t* payload) {

   uint8_t buffer[2048];
   uint8_t iCnt = 0;
   uint8_t jCnt = 0;
   uint32_t len = 0;
   bool ponComa = FALSE;

   switch (Code) {
      case COAP_CODE_REQ_GET:
		// La aplicacion no necesita este recurso, se aprovecha
		// para pruebas unitarias

		// prepara la respuesta con el valor de los parametros de configuracion
        buffer[0] = 0;

		len = uocapp_cc_s(buffer, len, "{", 1);
		len = uocapp_cc_pv(buffer, len, PARAM_SINCRONIZACION, uocapp_vars.sincronizacion);
		len = uocapp_cc_s(buffer, len, ",", 1);
		len = uocapp_cc_pv(buffer, len, PARAM_PERIODO, uocapp_vars.tarea.periodo);
		len = uocapp_cc_s(buffer, len, ",\"", 2);
		len = uocapp_cc_sd(buffer, len, PARAM_SENSORES_ACTIVOS);
		len = uocapp_cc_s(buffer, len, "\":\"", 3);
		for (iCnt = 0; iCnt < MAX_SENSORES; iCnt++) {
			if (uocapp_vars.sensores[iCnt].activo) {
				if (iCnt > 0) {
					len = uocapp_cc_s(buffer, len, ",", 1);
				}
				len = uocapp_cc_sd(buffer, len, uocapp_vars.sensores[iCnt].id);
			}
		}
		len = uocapp_cc_s(buffer, len, "\",\"", 3);
		len = uocapp_cc_sd(buffer, len, PARAM_SERVIDORES);
		len = uocapp_cc_s(buffer, len, "\":\"[", 3);

		for (iCnt = 0; iCnt < MAX_SERVIDORES; iCnt++) {
			if (len, uocapp_vars.servidores[iCnt].activo) {
				if (ponComa) {
					len = uocapp_cc_s(buffer, len, ",[", 2);
				}
				ponComa = TRUE;
				for (jCnt = 0; jCnt < 16; jCnt++) {
					if (jCnt > 0 && jCnt % 2 == 0) {
						len = uocapp_cc_s(buffer, len, ":", 1);
					}
					len = uocapp_cc_hex(buffer, len, uocapp_vars.servidores[iCnt].ipv6Addr[jCnt]);
				}
				len = uocapp_cc_s(buffer, len, "]:", 2);
				len = uocapp_cc_d(buffer, len, uocapp_vars.servidores[iCnt].puerto);
			}
		}
		len = uocapp_cc_s(buffer, len, "\"", 1);
		len = uocapp_cc_s(buffer, len, "}", 1);

        printf("Respuesta GET %s\n", buffer);

        break;

      case COAP_CODE_REQ_POST:
		// Recuperamos el payload
        uocapp_modificar_parametros(payload);

		// La respuesta solo marca que ha sido correcto, no se devuelven datos

        break;
      default:
         // error
    	  break;
   }
}

void uocapp_tarea_planificada() {
	uocapp_tarea_planificada_exec();
}

void uocapp_tarea_planificada_exec() {
	uint8_t buffer[127];
	uint32_t len = 0;

	len = uocapp_lectura_sensores(buffer, 0);
	uocapp_coap_send(buffer, len);
	len = uocapp_lectura_sensores(buffer, 3);
	uocapp_coap_send(buffer, len);

	len = uocapp_lectura_sensores_estado(buffer);
	uocapp_coap_send(buffer, len);

	buffer[0] = 0;
	len = 0;
	len = uocapp_cc_s(buffer, len, "{\"f\":", 5);
	len = uocapp_cc_ld(buffer, len, uocapp_vars.sincronizacion);
	len = uocapp_cc_s(buffer, len, "}", 1);
	uocapp_coap_send(buffer, len);
}

uint32_t uocapp_lectura_sensores_estado(uint8_t* buffer) {
	uint8_t iCnt = 0;
	uint32_t len = 0;

	buffer[0] = 0;
	len = uocapp_cc_s(buffer, len, "{\"e\":{", 6);
	for (iCnt = 0; iCnt < MAX_ESTADO; iCnt++) {
		if(iCnt > 0) {
			len = uocapp_cc_s(buffer, len, ",", 1);
		}
		if (uocapp_vars.estado[iCnt].sen != NULL) {
			len = uocapp_cc_pv(buffer, len, uocapp_vars.estado[iCnt].idStatus,
					STATUS++);
		}else {
			len = uocapp_cc_s(buffer, len, "\"", 1);
			len = uocapp_cc_sd(buffer, len, uocapp_vars.estado[iCnt].idStatus);
			len = uocapp_cc_s(buffer, len, "\":-1", 4);
		}
	}
	len = uocapp_cc_s(buffer, len, "}}", 2);
	return len;
}

uint32_t uocapp_lectura_sensores(uint8_t* buffer, uint8_t idx) {
	uint8_t iCnt = 0;
	uint32_t len = 0;
	bool ponComa = FALSE;

	buffer[0] = 0;
	len = uocapp_cc_s(buffer, len, "{\"s\":{", 6);
	for (iCnt = idx; iCnt < MAX_SENSORES && iCnt < idx + 3; iCnt++) {
		if (uocapp_vars.sensores[iCnt].activo) {
			if(ponComa) {
				len = uocapp_cc_s(buffer, len, ",", 1);
			}
			ponComa = TRUE;
			if (uocapp_vars.sensores[iCnt].sen != NULL) {
				len = uocapp_cc_pv(buffer, len, uocapp_vars.sensores[iCnt].id,
						SENSOR++);
			}else {
				len = uocapp_cc_sd(buffer, len, uocapp_vars.sensores[iCnt].id);
				len = uocapp_cc_s(buffer, len, ":-1", 3);
			}
		}
	}
	len = uocapp_cc_s(buffer, len, "}}", 2);
	return len;
}

void uocapp_coap_send(uint8_t* respuesta, uint32_t len) {
   int iCnt;

   printf("Enviar %s\n", respuesta);
   for (iCnt = 0; iCnt < MAX_SERVIDORES; iCnt++) {
	   if (uocapp_vars.servidores[iCnt].activo) {
	       printf("  a [%02x%02x:%02x%02x:%02x%02x:%02x%02x:%02x%02x:%02x%02x:%02x%02x:%02x%02x]:%d\n",
	    		uocapp_vars.servidores[iCnt].ipv6Addr[0], uocapp_vars.servidores[iCnt].ipv6Addr[1],
	    		uocapp_vars.servidores[iCnt].ipv6Addr[2], uocapp_vars.servidores[iCnt].ipv6Addr[3],
	    		uocapp_vars.servidores[iCnt].ipv6Addr[4], uocapp_vars.servidores[iCnt].ipv6Addr[5],
	    		uocapp_vars.servidores[iCnt].ipv6Addr[6], uocapp_vars.servidores[iCnt].ipv6Addr[7],
	    		uocapp_vars.servidores[iCnt].ipv6Addr[8], uocapp_vars.servidores[iCnt].ipv6Addr[9],
	    		uocapp_vars.servidores[iCnt].ipv6Addr[10], uocapp_vars.servidores[iCnt].ipv6Addr[11],
	    		uocapp_vars.servidores[iCnt].ipv6Addr[12], uocapp_vars.servidores[iCnt].ipv6Addr[13],
	    		uocapp_vars.servidores[iCnt].ipv6Addr[14], uocapp_vars.servidores[iCnt].ipv6Addr[15],
	    		uocapp_vars.servidores[iCnt].puerto);
	   }
   }
}

void uocapp_modificar_parametros(uint8_t* peticion) {
	// La peticion llega en formato JSON
	// {<id_pametro>:<valor parametro>, ...}
	uint8_t idParamero;
	int8_t control;
	uint8_t buffer[100];
	bool esValor;

	printf("Recibido POST %s\n", peticion);

	if (peticion[0] != 0) {
		control = 0;
		esValor = FALSE;
		while (control != -1) {
			control = uocapp_parsea_peticion(peticion, control, buffer);
			if (esValor) {
				switch(idParamero) {
				case PARAM_SINCRONIZACION:
					uocapp_vars.sincronizacion = uocapp_atoi(buffer, 10);
					break;
				case PARAM_PERIODO:
					uocapp_modifica_planificacion(uocapp_atoi(buffer, 10));
					break;
				case PARAM_SENSORES_ACTIVOS:
					uocapp_parsea_lista_sensores(buffer, uocapp_trata_sensor);
					break;
				case PARAM_SERVIDORES:
					uocapp_parsea_param_servidor(buffer, uocapp_trata_direccion_servidor);
					break;
				}
			}else {
				buffer[uocapp_len(buffer)-1] = 0;
				idParamero = uocapp_atoi(buffer+1, 10);
			}
			esValor = !esValor;
		}
	}
}

uint32_t uocapp_parsea_peticion(uint8_t* json, uint32_t init, uint8_t* buffer) {
	uint8_t c = 0;
	bool enString = FALSE;
	uint32_t cinicio = 0;
	uint32_t iCnt = 0;
	uint32_t len_json = uocapp_len(json);
	for (iCnt = init; iCnt < len_json; iCnt++) {
		c = json[iCnt];
		if (c == '{' && !enString) {
			cinicio = iCnt + 1;
		}
		else if ((c == ',' || c==':') && !enString) {
			if (cinicio != 0) {
				memcpy(buffer, &json[cinicio], iCnt-cinicio);
				buffer[iCnt-cinicio] = 0;
				return iCnt;
			}
			cinicio = iCnt + 1;
		}
		else if (c == '}' && !enString) {
			if (cinicio != 0) {
				memcpy(buffer, &json[cinicio], iCnt-cinicio);
				buffer[iCnt-cinicio] = 0;
				return -1;
			}
			cinicio = 0;
		}
		else if (c == '"') {
			enString = !enString;
		}
	}
	return -1;
}

void uocapp_parsea_lista_sensores(uint8_t* lista, _uocapp_trata_sensor callback) {
	// "1,2,3"
	uint8_t iCnt = 0;
	uint8_t enNumero = 0;
	uint8_t buffer[10];
	uint32_t len_lista = uocapp_len(lista);

	// Activa todos los sensores
	if (len_lista == 3 && lista[1] == 'T') {
		for (iCnt = 0; iCnt < MAX_SENSORES; iCnt++) {
			uocapp_vars.sensores[iCnt].activo = TRUE;
		}
	}
	else if (len_lista == 3 && lista[1] == 'N') {
		// Inactiva todos los sensores
		for (iCnt = 0; iCnt < MAX_SENSORES; iCnt++) {
			uocapp_vars.sensores[iCnt].activo = FALSE;
		}
	}
	else {
		// Inactiva todos los sensores
		for (iCnt = 0; iCnt < MAX_SENSORES; iCnt++) {
			uocapp_vars.sensores[iCnt].activo = FALSE;
		}
		// Activa los sensores que haya en la lista
		for (iCnt = 0; iCnt < len_lista; iCnt++) {
			if (lista[iCnt] < '0' || lista[iCnt] > '9') {
				if (enNumero) {
					memcpy(buffer, &lista[enNumero], iCnt-enNumero);
					buffer[iCnt-enNumero] = 0;
					callback(uocapp_atoi(buffer, 10));
				}
				enNumero  = 0;
			}
			else if (!enNumero){
				enNumero = iCnt;
			}
		}
	}
}

void uocapp_trata_sensor(uint8_t idSensor) {
	uint8_t iCnt = 0;
	for (iCnt = 0; iCnt < MAX_SENSORES; iCnt++) {
	   if (uocapp_vars.sensores[iCnt].id == idSensor) {
		  uocapp_vars.sensores[iCnt].activo = TRUE;
	   }
	}
}

void uocapp_parsea_param_servidor(uint8_t* servidor, _uocapp_trata_direccion_servidor callback) {
	// "0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF"
	uint32_t iCnt = 0;
	uint32_t jCnt = 0;
	uint8_t idServidor = 0;
	uint8_t aux = 0;
	uint8_t strservidor[33];
	uint8_t strpuerto[5];
	uint32_t len = uocapp_len(servidor);

	idServidor = servidor[1] - '0';
	if (servidor[2] == '-') {
		for (iCnt = idServidor; iCnt < MAX_SERVIDORES; iCnt++) {
			uocapp_vars.servidores[iCnt].activo = FALSE;
		}
	}else {
		for (iCnt = 0; iCnt < len - 7; iCnt++) {
			if (servidor[iCnt + 2] == ':') {
				for (jCnt = 0; jCnt < 39 - len; jCnt++) {
					strservidor[aux++] = '0';
				}
			}else
				strservidor[aux++] = servidor[iCnt + 2];
		}
		strservidor[32] = 0;
		memcpy(strpuerto, servidor + (len - 5), 4);
		strpuerto[4] = 0;
		callback(strservidor, (uint16_t)uocapp_atoi(strpuerto, 16), idServidor);
	}
}

void uocapp_trata_direccion_servidor(uint8_t* ipv6, uint16_t puerto, uint8_t idServidor) {
	uint8_t ipv6_bytes[16];
	uint8_t ipv6_g[5];
	uint32_t iCnt = 0;
	uint32_t cinicio = 0;
	uint32_t iCntByte = 0;

	for (iCnt = 0; iCnt < 8; iCnt++) {
		memset(ipv6_g, 0, 5);
		memcpy(ipv6_g, ipv6 + cinicio, 4);
		cinicio += 4;
		int ig = uocapp_atoi(ipv6_g, 16);
		ipv6_bytes[iCntByte++] = ig / 256;
		ipv6_bytes[iCntByte++] = ig % 256;
	}

	uocapp_vars.servidores[idServidor].puerto = puerto;
	uocapp_vars.servidores[idServidor].activo = TRUE;
	memcpy(uocapp_vars.servidores[idServidor].ipv6Addr, ipv6_bytes, 16);
}

void uocapp_modifica_planificacion(uint32_t periodo) {
	uocapp_vars.tarea.periodo = periodo * 1000;

	if (periodo == 0 && uocapp_vars.tarea.enEjecucion) {
		printf("  parar tarea\n");
		uocapp_vars.tarea.enEjecucion = FALSE;
	}
	else if (periodo > 0) {
		printf("  establecer periodo tarea %d \n", periodo);
		if (!uocapp_vars.tarea.enEjecucion) {
			printf("    iniciar tarea\n");
		}
	}
}

uint32_t uocapp_len(uint8_t* s) {
	uint32_t ret = 0;
	if (s != NULL) {
		for (ret = 0; s[ret] != 0; ret++);
	}
	return ret;
}

uint32_t uocapp_cc_pv(uint8_t* buffer, uint32_t init, uint8_t p, uint32_t v) {
	uint32_t len = init;
	len = uocapp_cc_s(buffer, len, "\"", 1);
	len = uocapp_cc_sd(buffer, len, p);
	len = uocapp_cc_s(buffer, len, "\":", 2);
	len = uocapp_cc_ld(buffer, len, v);
	return len;
}

uint32_t uocapp_cc_s(uint8_t* buffer, uint32_t init, char* c, uint8_t l) {
	uint32_t len = init;
	uint8_t iCnt = 0;
	for (iCnt = 0; iCnt < l; iCnt++) {
		buffer[len++] = c[iCnt];
	}
	buffer[len] = 0;
	return len;
}

uint32_t uocapp_cc_ld(uint8_t* buffer, uint32_t init, uint32_t ld) {
	uint32_t len = init;
	uint32_t cld = ld;
	uint32_t max = 1000000000;
	uint8_t s = 0;
	int ya = 0;
	while (max > 1) {
		s = cld / max;
		if (s > 0 || (s == 0 && ya)) {
			ya = 1;
			buffer[len++] = digitos[s];
		}
		cld = cld % max;
		max /= 10;
	}
	buffer[len++] = digitos[cld];
	buffer[len] = 0;
	return len;
}
uint32_t uocapp_cc_d(uint8_t* buffer, uint32_t init, uint16_t ld) {
	uint32_t len = init;
	uint16_t val = ld;
	if (val / 10000 != 0) {
		buffer[len++] = digitos[val / 10000];
	}
	val = val % 10000;
	if (val / 1000 != 0 || len != init) {
		buffer[len++] = digitos[val / 1000];
	}
	val = val % 1000;
	if (val / 100 != 0 || len != init) {
		buffer[len++] = digitos[val / 100];
	}
	val = val % 100;
	if (val / 10 != 0 || len != init) {
		buffer[len++] = digitos[val / 10];
	}
	val = val % 10;
	buffer[len++] = digitos[val];
	buffer[len] = 0;
	return len;
}

uint32_t uocapp_cc_sd(uint8_t* buffer, uint32_t init, uint8_t ld) {
	uint32_t len = init;
	uint8_t val = ld;
	if (val / 100 != 0) {
		buffer[len++] = digitos[val / 100];
	}
	val = val % 100;
	if (val / 10 != 0 || len != init) {
		buffer[len++] = digitos[val / 10];
	}
	val = val % 10;
	buffer[len++] = digitos[val];
	buffer[len] = 0;
	return len;
}

uint32_t uocapp_cc_hex(uint8_t* buffer, uint32_t init, uint8_t ld) {
	uint32_t len = init;
	buffer[len++] = digitos_hex[ld / 16];
	buffer[len++] = digitos_hex[ld % 16];
	buffer[len] = 0;
	return len;
}

uint32_t uocapp_atoi(uint8_t* s, uint8_t base) {
	uint32_t ret = 0;
	uint32_t mult = 1;
	uint32_t iCnt = 0;
	uint8_t calc = 0;
	uint32_t len = uocapp_len(s);
	for (iCnt = 0; iCnt < len; iCnt++){
		calc = 0;
		if (s[len - 1 - iCnt] >= '0' && s[len - 1 - iCnt] <= '9') {
			calc = s[len - 1 - iCnt] - '0';
		}else if (s[len - 1 - iCnt] >= 'a' && s[len - 1 - iCnt] <= 'f') {
			calc = s[len - 1 - iCnt] - 'a' + 10;
		}else if (s[len - 1 - iCnt] >= 'A' && s[len - 1 - iCnt] <= 'F') {
			calc = s[len - 1 - iCnt] - 'A' + 10;
		}
		ret = ret + mult * calc;
		mult *= base;
	}
	return ret;
}

