#ifndef __UOCAPP_H
#define __UOCAPP_H

/**
\addtogroup AppCoAP
\{
\addtogroup uocapp
\{
*/

#include "opencoap.h"
#include "opentimers.h"
#include "opensensors.h"

//=========================== define ==========================================

#define PARAM_SINCRONIZACION 0
#define PARAM_SERVIDORES 1
#define PARAM_PERIODO 2
#define PARAM_SENSORES_ACTIVOS 3

#define MAX_SERVIDORES 10
#define MAX_SENSORES 6
#define MAX_ESTADO 2

#define DEFAULT_TIME 300

static const uint8_t ipAddr_openvisualizer[]  = {0xbb, 0xbb, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, \
                                           	     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01}; // [bbbb::1]
static const uint8_t SENSORES_ACTIVOS[] = {
	SENSOR_TEMPERATURE
	,SENSOR_HUMIDITY
	,SENSOR_LIGHT
	,SENSOR_XACCELERATION
	,SENSOR_YACCELERATION
	,SENSOR_ZACCELERATION
};

static const uint8_t SENSORES_ACTIVOS_ESTADO[] = {
	SENSOR_ADCTEMPERATURE,
	SENSOR_ADCVDD
};

//=========================== typedef =========================================

/**
\brief Template de la funcion invocada cuando se trata la lista de sensores activos
*/
typedef void (*_uocapp_trata_sensor)(uint8_t);
/**
\brief Template de la funcion invocada cuando se trata la lista de sensores servidores
*/
typedef void (*_uocapp_trata_direccion_servidor)(uint8_t*, uint16_t, uint8_t);
/**
\brief Estructura con los datos de la tarea que manda info a la parte web
*/
typedef struct {
   opentimer_id_t timerId; // id del timer de la tarea planificada
   bool enEjecucion; // indicador de que la tarea esta en ejecucion
   uint32_t periodo; // periodo de la tarea planificada en ms
} uocapp_vars_timer_t;
/**
\brief Estructura que representa los datos de un sensor
*/
typedef struct {
  uint8_t id; // id del sensor
  bool activo;
  opensensors_resource_desc_t* sen; // datos del sensor
} uocapp_vars_sensor_t;
/**
\brief Estructura que representa los datos de un sensor
*/
typedef struct {
  uint8_t id; // id del sensor
  uint8_t idStatus; // id del parametro de estado
  opensensors_resource_desc_t* sen; // datos del sensor
} uocapp_vars_estado_t;
/**
\brief Estructura que representa los datos del un servidor al que mandar informacion
*/
typedef struct {
  bool activo;
  uint16_t puerto;
  uint8_t ipv6Addr[16];
} uocapp_vars_servidor_t;
/**
\brief Estructura de datos internos de la aplicacion
*/
typedef struct {
   uocapp_vars_timer_t tarea;

   coap_resource_desc_t coap; // datos del recurso CoAP

   uocapp_vars_sensor_t sensores[MAX_SENSORES]; // sensores

   uocapp_vars_estado_t estado[MAX_ESTADO]; // sensores para parametros de estado

   uocapp_vars_servidor_t servidores[MAX_SERVIDORES]; // servidores a los que hay que informar la respuesta

   uint32_t sincronizacion; // parametro de sincronizacion con la parte web
} uocapp_vars_t;

//=========================== variables =======================================

//=========================== prototypes ======================================

void uocapp_init(void);

/**
\}
\}
*/

#endif

