/**
\brief This is a standalone program to program the EUI-64 address of a the GINA and
basestation GINA boards.

Set the variables 'board_type', 'board_version' and 'board_id', compile and run the
program.

It will store the corresponding EUI64 into the information memory space of
the MSP430, which does not get erased, ever. The available memory ranges are:
  - 0x10ee-0x10f5 [8B] to store the EUI64
  - 0x10c4-0x10d9 [22B] reserved for future use.

The EUI-64 naming convention is: 14-15-92-xx yy-yy-zz-zz 
where:
- xx is the type of board:
  . 0x09 for GINA ('9' looks like a 'g')
  . 0x0b for basestation GINA
- yy-yy is the version
  . 0x022b for a GINA 2.2b
  . 0x022c for a GINA 2.2c
  . 0x0301 for a GINA basestation MSP1 ('3' looks like a rotated 'm')
- zz-zz is the unique identifier of the board, in hex, big endian (the one 
  printed on the sticker).
 
\author Thomas Watteyne <watteyne@eecs.berkeley.edu>, August 2010
*/

#ifndef __PROGRAM_EUI64_H
#define __PROGRAM_EUI64_H

#ifdef LABEL_0028
#define BOARD_CALIBRATION {0x84,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0x18,0x80,0xab,0x0b,0xe4,0x0d,0x23,0x80,0xfd,0x06,0x52,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x8a,0x8f,0x94,0x8e,0x84,0x8d,0xc9,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0028
#endif

#ifdef LABEL_0029
#define BOARD_CALIBRATION {0xce,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x4b,0x7f,0x92,0x0b,0xc3,0x0d,0xc1,0x7f,0xea,0x06,0x3d,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x88,0x8f,0x8d,0x8e,0x7a,0x8d,0xb6,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0029
#endif

#ifdef LABEL_002a
#define BOARD_CALIBRATION {0xb1,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xe2,0x7e,0x81,0x0b,0xba,0x0d,0xfc,0x7e,0xe5,0x06,0x3b,0x08,0xfe,0x08,0x14,0x15, \
                           0x92,0x0b,0x03,0x01,0x00,0x02,0x01,0x08,0xa9,0x8f,0xab,0x8e,0x9d,0x8d,0xdf,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x002a
#endif

#ifdef LABEL_002b
#define BOARD_CALIBRATION {0x9a,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x8d,0x81,0xae,0x0b,0xe0,0x0d,0xbe,0x81,0xff,0x06,0x50,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x91,0x8f,0x95,0x8e,0x86,0x8d,0xc1,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x002b
#endif

#ifdef LABEL_002c
#define BOARD_CALIBRATION {0x29,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x3c,0x7e,0x77,0x0b,0xb6,0x0d,0x7e,0x7e,0xdd,0x06,0x36,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xa6,0x8f,0xab,0x8e,0x99,0x8d,0xdc,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x002c
#endif

#ifdef LABEL_002d
#define BOARD_CALIBRATION {0x74,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xb4,0x81,0xc6,0x0b,0xee,0x0d,0xf0,0x81,0x0d,0x07,0x5c,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xa8,0x8f,0xab,0x8e,0x9c,0x8d,0xda,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x002d
#endif

#ifdef LABEL_002e
#define BOARD_CALIBRATION {0xaa,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x98,0x80,0xad,0x0b,0xd5,0x0d,0xda,0x80,0xfe,0x06,0x4c,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x8c,0x8f,0x91,0x8e,0x82,0x8d,0xb6,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x002e
#endif

#ifdef LABEL_002f
#define BOARD_CALIBRATION {0xc5,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x8b,0x81,0xa7,0x0b,0xd4,0x0d,0xc8,0x81,0xf9,0x06,0x49,0x08,0xfe,0x08,0x14,0x15, \
                           0x92,0x09,0x02,0x2c,0x00,0x2f,0x01,0x08,0x94,0x8f,0x99,0x8e,0x8a,0x8d,0xcb,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x002f
#endif

#ifdef LABEL_0030
#define BOARD_CALIBRATION {0xdc,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x1e,0x80,0x96,0x0b,0xce,0x0d,0x77,0x80,0xee,0x06,0x44,0x08,0xfe,0x08,0x14,0x15, \
                           0x92,0x09,0x02,0x2c,0x00,0x30,0x01,0x08,0xa0,0x8f,0xa8,0x8e,0x96,0x8d,0xd6,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x0030
#endif

#ifdef LABEL_0031
#define BOARD_CALIBRATION {0x2f,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x67,0x81,0xb2,0x0b,0xe0,0x0d,0xea,0x81,0xfe,0x06,0x4c,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xa8,0x8f,0xaa,0x8e,0x9d,0x8d,0xd4,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0031
#endif

#ifdef LABEL_0032
#define BOARD_CALIBRATION {0x7d,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x03,0x00, \
                           0x49,0x7f,0x8e,0x0b,0xbe,0x0d,0x59,0x7f,0xed,0x06,0x40,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xa2,0x8f,0xa8,0x8e,0x99,0x8d,0x68,0x87}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0032
#endif

#ifdef LABEL_0033
#define BOARD_CALIBRATION {0x93,0x86,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xbc,0x81,0xc0,0x0b,0xf2,0x0d,0x01,0x82,0x09,0x07,0x5a,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9a,0x8f,0x9b,0x8e,0x96,0x8d,0xd2,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0033
#endif

#ifdef LABEL_0034
#define BOARD_CALIBRATION {0x7a,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x74,0x7f,0xa6,0x0b,0xe0,0x0d,0xb7,0x7f,0xf8,0x06,0x50,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x97,0x8f,0x9d,0x8e,0x8f,0x8d,0xd9,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0034
#endif

#ifdef LABEL_0035
#define BOARD_CALIBRATION {0x2d,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xef,0x80,0xa4,0x0b,0xd2,0x0d,0x5c,0x81,0xf6,0x06,0x47,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9b,0x8f,0x9e,0x8e,0x91,0x8d,0xc7,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0035
#endif

#ifdef LABEL_0036
#define BOARD_CALIBRATION {0x59,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x57,0x7e,0x7f,0x0b,0xb8,0x0d,0x63,0x7e,0xe4,0x06,0x3b,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9e,0x8f,0xa4,0x8e,0x93,0x8d,0xd5,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0036
#endif

#ifdef LABEL_0037
#define BOARD_CALIBRATION {0xa4,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0x12,0x82,0xaa,0x0b,0xd1,0x0d,0x3a,0x82,0xfc,0x06,0x49,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x92,0x8f,0x9a,0x8e,0x8b,0x8d,0xcf,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0037
#endif

#ifdef LABEL_0038
#define BOARD_CALIBRATION {0x3e,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x7d,0x80,0x96,0x0b,0xc9,0x0d,0xef,0x80,0xed,0x06,0x3f,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x8c,0x8f,0x93,0x8e,0x80,0x8d,0xb5,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0038
#endif

#ifdef LABEL_0039
#define BOARD_CALIBRATION {0xd9,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0x0b,0x81,0xab,0x0b,0xd7,0x0d,0x52,0x81,0xfc,0x06,0x4a,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x95,0x8f,0x96,0x8e,0x87,0x8d,0xc4,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0039
#endif

#ifdef LABEL_003a
#define BOARD_CALIBRATION {0x36,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0x15,0x82,0xc3,0x0b,0xed,0x0d,0x29,0x82,0x0b,0x07,0x5b,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9c,0x8f,0xa3,0x8e,0x98,0x8d,0xdb,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x003a
#endif

#ifdef LABEL_003b
#define BOARD_CALIBRATION {0xe2,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x2d,0x7f,0x89,0x0b,0xbf,0x0d,0x69,0x7f,0xe8,0x06,0x3d,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x95,0x8f,0x96,0x8e,0x86,0x8d,0xcb,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x003b
#endif

#ifdef LABEL_003c
#define BOARD_CALIBRATION {0xb8,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xa0,0x80,0xa7,0x0b,0xde,0x0d,0xb3,0x80,0xfc,0x06,0x52,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x98,0x8f,0xa2,0x8e,0x98,0x8d,0xd9,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x003c
#endif

#ifdef LABEL_003d
#define BOARD_CALIBRATION {0x44,0x87,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xcf,0x81,0xa9,0x0b,0xdc,0x0d,0x38,0x82,0xf9,0x06,0x4b,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9f,0x8f,0xa3,0x8e,0x91,0x8d,0xd5,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x003d
#endif

#ifdef LABEL_003e
#define BOARD_CALIBRATION {0xf6,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xa0,0x80,0x9b,0x0b,0xca,0x0d,0x07,0x81,0xf1,0x06,0x43,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x90,0x8f,0x94,0x8e,0x7f,0x8d,0xc2,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x003e
#endif

#ifdef LABEL_003f
#define BOARD_CALIBRATION {0xaa,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x10,0x80,0x88,0x0b,0xb7,0x0d,0x30,0x80,0xe9,0x06,0x3a,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xaa,0x8f,0xb0,0x8e,0xa1,0x8d,0xd6,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x003f
#endif

#ifdef LABEL_0040
#define BOARD_CALIBRATION {0x61,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xcc,0x80,0xae,0x0b,0xde,0x0d,0x1b,0x81,0xfd,0x06,0x4e,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9e,0x8f,0xa6,0x8e,0x99,0x8d,0xde,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0040
#endif

#ifdef LABEL_0041
#define BOARD_CALIBRATION {0xde,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0x9a,0x80,0xa2,0x0b,0xd3,0x0d,0xd4,0x80,0xf8,0x06,0x49,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x98,0x8f,0x9d,0x8e,0x8d,0x8d,0xd0,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0041
#endif

#ifdef LABEL_0042
#define BOARD_CALIBRATION {0x8e,0x87,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xfc,0x7d,0x6f,0x0b,0xae,0x0d,0x1a,0x7e,0xda,0x06,0x32,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9c,0x8f,0xa3,0x8e,0x95,0x8d,0xe0,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0042
#endif

#ifdef LABEL_0043
#define BOARD_CALIBRATION {0x0a,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0x2e,0x7e,0x64,0x0b,0x9f,0x0d,0x67,0x7e,0xd1,0x06,0x28,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x91,0x8f,0x96,0x8e,0x84,0x8d,0xca,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0043
#endif

#ifdef LABEL_0044
#define BOARD_CALIBRATION {0xdb,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xf1,0x7e,0x72,0x0b,0xac,0x0d,0x5a,0x7f,0xd8,0x06,0x2d,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x96,0x8f,0x9b,0x8e,0x8e,0x8d,0xd1,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0044
#endif

#ifdef LABEL_0045
#define BOARD_CALIBRATION {0x34,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xb5,0x7e,0x6a,0x0b,0x9e,0x0d,0xd4,0x7e,0xd7,0x06,0x2a,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x8e,0x8f,0x97,0x8e,0x8a,0x8d,0xc0,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0045
#endif

#ifdef LABEL_0046
#define BOARD_CALIBRATION {0xe3,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0x1e,0x81,0x94,0x0b,0xc1,0x0d,0x29,0x81,0xf1,0x06,0x43,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x91,0x8f,0x97,0x8e,0x85,0x8d,0xb8,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0046
#endif

#ifdef LABEL_0047
#define BOARD_CALIBRATION {0x9c,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x15,0x80,0xbc,0x0b,0xef,0x0d,0x50,0x80,0x06,0x07,0x59,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xb2,0x8f,0xb5,0x8e,0xa5,0x8d,0x78,0x87}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0047
#endif

#ifdef LABEL_0048
#define BOARD_CALIBRATION {0x26,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0x95,0x80,0xa5,0x0b,0xd5,0x0d,0xb2,0x80,0xf7,0x06,0x4a,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xa9,0x8f,0xae,0x8e,0xa0,0x8d,0x63,0x87}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0048
#endif

#ifdef LABEL_0049
#define BOARD_CALIBRATION {0xb3,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xcf,0x7e,0x63,0x0b,0x9f,0x0d,0x33,0x7f,0xcf,0x06,0x27,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xaa,0x8f,0xb0,0x8e,0x9e,0x8d,0xd6,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0049
#endif

#ifdef LABEL_004a
#define BOARD_CALIBRATION {0x20,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xeb,0x80,0x85,0x0b,0xba,0x0d,0x51,0x81,0xe4,0x06,0x36,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x88,0x8f,0x8f,0x8e,0x83,0x8d,0xc4,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x004a
#endif

#ifdef LABEL_004b
#define BOARD_CALIBRATION {0x85,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x10,0x7f,0x91,0x0b,0xcf,0x0d,0x3f,0x7f,0xee,0x06,0x46,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x8b,0x8f,0x93,0x8e,0x82,0x8d,0xcf,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x004b
#endif

#ifdef LABEL_004c
#define BOARD_CALIBRATION {0x5a,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0x81,0x81,0xd1,0x0b,0xfe,0x0d,0xc3,0x81,0x14,0x07,0x62,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x92,0x8f,0x94,0x8e,0x88,0x8d,0xc7,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x004c
#endif

#ifdef LABEL_004d
#define BOARD_CALIBRATION {0x5b,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xd0,0x80,0xb3,0x0b,0xe4,0x0d,0x37,0x81,0xff,0x06,0x50,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9a,0x8f,0x9f,0x8e,0x8f,0x8d,0xc4,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x004d
#endif

#ifdef LABEL_004e
#define BOARD_CALIBRATION {0xf7,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x31,0x81,0x9d,0x0b,0xcf,0x0d,0x76,0x81,0xf3,0x06,0x45,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x98,0x8f,0x9f,0x8e,0x8b,0x8d,0xd1,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x004e
#endif

#ifdef LABEL_004f
#define BOARD_CALIBRATION {0x64,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0x44,0x81,0xbf,0x0b,0xf1,0x0d,0x6e,0x81,0x0a,0x07,0x5c,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9a,0x8f,0x9b,0x8e,0x94,0x8d,0xcf,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x004f
#endif

#ifdef LABEL_0050
#define BOARD_CALIBRATION {0x50,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0x9e,0x7f,0x7c,0x0b,0xaa,0x0d,0xb8,0x7f,0xe1,0x06,0x34,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x99,0x8f,0xa0,0x8e,0x93,0x8d,0xc9,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0050
#endif

#ifdef LABEL_0051
#define BOARD_CALIBRATION {0x76,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0x78,0x7e,0x92,0x0b,0xcd,0x0d,0xb1,0x7e,0xee,0x06,0x44,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x98,0x8f,0x9e,0x8e,0x90,0x8d,0xd4,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0051
#endif

#ifdef LABEL_0052
#define BOARD_CALIBRATION {0x29,0x7b,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x0c,0x80,0x87,0x0b,0xbe,0x0d,0xff,0x7f,0xeb,0x06,0x40,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xa9,0x8f,0xab,0x8e,0x98,0x8d,0xdb,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x0052
#endif

#ifdef LABEL_0053
#define BOARD_CALIBRATION {0x71,0x7b,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0xee,0x7f,0x80,0x0b,0xb0,0x0d,0x35,0x80,0xe2,0x06,0x34,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xa6,0x8f,0xa7,0x8e,0x9c,0x8d,0xd9,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x0053
#endif

#ifdef LABEL_0054
#define BOARD_CALIBRATION {0x51,0x7b,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xc1,0x7f,0x92,0x0b,0xcc,0x0d,0x50,0x80,0xe9,0x06,0x3f,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x95,0x8f,0x96,0x8e,0x83,0x8d,0xc1,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x0054
#endif

#ifdef LABEL_0055
#define BOARD_CALIBRATION {0x62,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x16,0x7e,0x61,0x0b,0x9d,0x0d,0x2e,0x7e,0xd1,0x06,0x2b,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x8e,0x8f,0x94,0x8e,0x84,0x8d,0xc9,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x0055
#endif

#ifdef LABEL_0056
#define BOARD_CALIBRATION {0x8d,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xab,0x80,0xa7,0x0b,0xd2,0x0d,0xd1,0x80,0xfb,0x06,0x48,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x7c,0x8f,0x83,0x8e,0x6f,0x8d,0xa8,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x0056
#endif

#ifdef LABEL_0057
#define BOARD_CALIBRATION {0xde,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x60,0x7f,0x8f,0x0b,0xc0,0x0d,0x5a,0x7f,0xee,0x06,0x3f,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x95,0x8f,0x9a,0x8e,0x89,0x8d,0xc7,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0057
#endif


#ifdef LABEL_0058
#define BOARD_CALIBRATION {0x56,0x7b,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xe0,0x7f,0x8d,0x0b,0xb0,0x0d,0x09,0x80,0xeb,0x06,0x35,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x8b,0x8f,0x91,0x8e,0x84,0x8d,0xca,0x86}	
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0058
#endif

#ifdef LABEL_0059
#define BOARD_CALIBRATION {0xed,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xdd,0x7e,0x77,0x0b,0xac,0x0d,0xe9,0x7e,0xe0,0x06,0x33,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x76,0x8f,0x7d,0x8e,0x6f,0x8d,0xbc,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0059
#endif

#ifdef LABEL_005a
#define BOARD_CALIBRATION {0x9f,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x06,0x80,0x89,0x0b,0xb7,0x0d,0x3a,0x80,0xe9,0x06,0x37,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x8c,0x8f,0x94,0x8e,0x86,0x8d,0xd4,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x005a
#endif

#ifdef LABEL_005b
#define BOARD_CALIBRATION {0x6f,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0xbe,0x81,0xd0,0x0b,0xf7,0x0d,0xf7,0x81,0x13,0x07,0x5e,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9b,0x8f,0x9d,0x8e,0x94,0x8d,0xd6,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x005b
#endif

#ifdef LABEL_005c
#define BOARD_CALIBRATION {0x6e,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0x6a,0x80,0xae,0x0b,0xe3,0x0d,0xa9,0x80,0xfe,0x06,0x51,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x95,0x8f,0x9b,0x8e,0x8b,0x8d,0xc0,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x005c
#endif

#ifdef LABEL_005d
#define BOARD_CALIBRATION {0x51,0x7b,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0xd9,0x7f,0x8e,0x0b,0xc8,0x0d,0x14,0x80,0xeb,0x06,0x42,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9a,0x8f,0xa2,0x8e,0x94,0x8d,0xd7,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x005d
#endif

#ifdef LABEL_005e
#define BOARD_CALIBRATION {0x1c,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xad,0x80,0xb9,0x0b,0xef,0x0d,0xf7,0x80,0x04,0x07,0x58,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9d,0x8f,0xa9,0x8e,0xa0,0x8d,0xd4,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x005e
#endif

#ifdef LABEL_005f
#define BOARD_CALIBRATION {0x09,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x1f,0x7f,0x65,0x0b,0x8f,0x0d,0x63,0x7f,0xd2,0x06,0x1f,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x8f,0x8f,0x95,0x8e,0x86,0x8d,0xc7,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x005f
#endif

#ifdef LABEL_0060
#define BOARD_CALIBRATION {0x51,0x86,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x3a,0x81,0xdf,0x0b,0x0f,0x0e,0x80,0x81,0x1b,0x07,0x6b,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9a,0x8f,0x9f,0x8e,0x91,0x8d,0xd6,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0060
#endif


#ifdef LABEL_0061
#define BOARD_CALIBRATION {0x49,0x7b,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xdc,0x7f,0x82,0x0b,0xb3,0x0d,0x2f,0x80,0xe2,0x06,0x33,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x95,0x8f,0x9d,0x8e,0x8b,0x8d,0xd0,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0061
#endif

#ifdef LABEL_0062
#define BOARD_CALIBRATION {0x7e,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xa4,0x7f,0xa0,0x0b,0xcf,0x0d,0xc3,0x7f,0xf7,0x06,0x47,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x82,0x8f,0x8e,0x8e,0x7c,0x8d,0xbd,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0062
#endif

#ifdef LABEL_0063
#define BOARD_CALIBRATION {0x8e,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x2d,0x80,0x92,0x0b,0xbc,0x0d,0x69,0x80,0xee,0x06,0x3a,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x90,0x8f,0x94,0x8e,0x83,0x8d,0xbc,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0063
#endif

#ifdef LABEL_0064
#define BOARD_CALIBRATION {0x86,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x0d,0x7f,0x88,0x0b,0xbf,0x0d,0x2a,0x7f,0xe9,0x06,0x3e,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x91,0x8f,0x94,0x8e,0x82,0x8d,0xcd,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0064
#endif

#ifdef LABEL_0065
#define BOARD_CALIBRATION {0x42,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x24,0x81,0xb2,0x0b,0xe3,0x0d,0x30,0x81,0x03,0x07,0x55,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x8c,0x8f,0x94,0x8e,0x88,0x8d,0xca,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0065
#endif

#ifdef LABEL_0066
#define BOARD_CALIBRATION {0x12,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x9b,0x80,0x6d,0x0b,0x92,0x0d,0xbf,0x80,0xd9,0x06,0x23,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x7f,0x8f,0x85,0x8e,0x74,0x8d,0xb6,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0066
#endif

#ifdef LABEL_0067
#define BOARD_CALIBRATION {0x39,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xb1,0x80,0x80,0x0b,0xad,0x0d,0x2b,0x81,0xe0,0x06,0x2d,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x90,0x8f,0x95,0x8e,0x86,0x8d,0xc9,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0067
#endif

#ifdef LABEL_0068
#define BOARD_CALIBRATION {0xdd,0x86,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xec,0x81,0xd9,0x0b,0x06,0x0e,0xde,0x81,0x1c,0x07,0x6b,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x91,0x8f,0x97,0x8e,0x89,0x8d,0xc1,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0068
#endif

#ifdef LABEL_0069
#define BOARD_CALIBRATION {0x36,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x28,0x80,0x82,0x0b,0xac,0x0d,0x80,0x80,0xe2,0x06,0x2f,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9e,0x8f,0xa5,0x8e,0x98,0x8d,0xd5,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0069
#endif

#ifdef LABEL_006a
#define BOARD_CALIBRATION {0x87,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x4c,0x80,0x8a,0x0b,0xb4,0x0d,0x73,0x80,0xea,0x06,0x36,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x92,0x8f,0x97,0x8e,0x85,0x8d,0xd3,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x006a
#endif

#ifdef LABEL_006b
#define BOARD_CALIBRATION {0x48,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0x79,0x82,0xc7,0x0b,0xf1,0x0d,0x83,0x82,0x10,0x07,0x5d,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xa9,0x8f,0xb0,0x8e,0xa1,0x8d,0x77,0x87}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x006b
#endif

#ifdef LABEL_006c
#define BOARD_CALIBRATION {0x5e,0x7a,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0xd9,0x7f,0xbc,0x0b,0xeb,0x0d,0x46,0x80,0x04,0x07,0x53,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x87,0x8f,0x89,0x8e,0x76,0x8d,0xb3,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x006c
#endif

#ifdef LABEL_006d
#define BOARD_CALIBRATION {0x79,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x67,0x80,0xb2,0x0b,0xdf,0x0d,0x55,0x80,0x06,0x07,0x53,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9f,0x8f,0xa9,0x8e,0x97,0x8d,0xdb,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x006d
#endif

#ifdef LABEL_006e
#define BOARD_CALIBRATION {0x05,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xab,0x80,0xa4,0x0b,0xce,0x0d,0x21,0x81,0xf5,0x06,0x41,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x8c,0x8f,0x94,0x8e,0x84,0x8d,0xc4,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x006e
#endif

#ifdef LABEL_006f
#define BOARD_CALIBRATION {0x8a,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x31,0x81,0xa3,0x0b,0xc7,0x0d,0x5d,0x81,0xf9,0x06,0x42,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x7f,0x8f,0x85,0x8e,0x74,0x8d,0xbc,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x006f
#endif

#ifdef LABEL_0070
#define BOARD_CALIBRATION {0x89,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x73,0x7f,0x8f,0x0b,0xc2,0x0d,0xaa,0x7f,0xec,0x06,0x3e,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x81,0x8f,0x84,0x8e,0x76,0x8d,0xb5,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0070
#endif

#ifdef LABEL_0071
#define BOARD_CALIBRATION {0x81,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0x9e,0x80,0xa0,0x0b,0xd8,0x0d,0x95,0x80,0xf8,0x06,0x4f,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x93,0x8f,0x9b,0x8e,0x93,0x8d,0xd4,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0071
#endif

#ifdef LABEL_0072
#define BOARD_CALIBRATION {0xee,0x7b,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xdc,0x7f,0x83,0x0b,0xb4,0x0d,0x03,0x80,0xe6,0x06,0x37,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x74,0x8f,0x7b,0x8e,0x69,0x8d,0xba,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0072
#endif

#ifdef LABEL_0073
#define BOARD_CALIBRATION {0x49,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x81,0x80,0xa1,0x0b,0xce,0x0d,0xc0,0x80,0xf6,0x06,0x44,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x6e,0x8f,0x75,0x8e,0x64,0x8d,0xa3,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0073
#endif

#ifdef LABEL_0074
#define BOARD_CALIBRATION {0x5c,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x2c,0x80,0x98,0x0b,0xce,0x0d,0x53,0x80,0xf2,0x06,0x46,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x85,0x8f,0x8e,0x8e,0x7f,0x8d,0xba,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0074
#endif

#ifdef LABEL_0075
#define BOARD_CALIBRATION {0x2d,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xc9,0x80,0xa8,0x0b,0xd8,0x0d,0x18,0x81,0xfa,0x06,0x4a,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x7f,0x8f,0x85,0x8e,0x75,0x8d,0xba,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0075
#endif

#ifdef LABEL_0076
#define BOARD_CALIBRATION {0x47,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xfa,0x80,0xa3,0x0b,0xd2,0x0d,0x3e,0x81,0xf8,0x06,0x47,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9a,0x8f,0x9f,0x8e,0x8f,0x8d,0xce,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0076
#endif

#ifdef LABEL_0077
#define BOARD_CALIBRATION {0xcc,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xa8,0x80,0xb4,0x0b,0xe4,0x0d,0x0b,0x81,0x00,0x07,0x4f,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9a,0x8f,0xa0,0x8e,0x91,0x8d,0xd4,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0077
#endif

#ifdef LABEL_0078
#define BOARD_CALIBRATION {0x6d,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xd6,0x7e,0x8f,0x0b,0xbf,0x0d,0x20,0x7f,0xea,0x06,0x3b,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x98,0x8f,0xa0,0x8e,0x92,0x8d,0xd9,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0078
#endif

#ifdef LABEL_0079
#define BOARD_CALIBRATION {0x5f,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xb9,0x80,0x80,0x0b,0xb5,0x0d,0xce,0x80,0xe5,0x06,0x39,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x83,0x8f,0x8d,0x8e,0x7b,0x8d,0xbd,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0079
#endif

#ifdef LABEL_007a
#define BOARD_CALIBRATION {0xec,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xff,0x7e,0x62,0x0b,0x8f,0x0d,0x6b,0x7f,0xce,0x06,0x1c,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x82,0x8f,0x8a,0x8e,0x80,0x8d,0xc0,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x007a
#endif

#ifdef LABEL_007b
#define BOARD_CALIBRATION {0x67,0x7b,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0xf3,0x7f,0x9c,0x0b,0xcd,0x0d,0x0b,0x80,0xf5,0x06,0x46,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x99,0x8f,0xa1,0x8e,0x94,0x8d,0xd9,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x007b
#endif

#ifdef LABEL_007c
#define BOARD_CALIBRATION {0x98,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xc8,0x80,0x9f,0x0b,0xd2,0x0d,0xde,0x80,0xf7,0x06,0x4a,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9d,0x8f,0xa3,0x8e,0x94,0x8d,0xd3,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x007c
#endif

#ifdef LABEL_007d
#define BOARD_CALIBRATION {0x01,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x0e,0x82,0xd5,0x0b,0xff,0x0d,0x14,0x82,0x18,0x07,0x66,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xa3,0x8f,0xaa,0x8e,0x9b,0x8d,0xd4,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x007d
#endif

#ifdef LABEL_007e
#define BOARD_CALIBRATION {0xcf,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x11,0x7f,0x6c,0x0b,0x9b,0x0d,0x1d,0x7f,0xd9,0x06,0x2a,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x88,0x8f,0x8b,0x8e,0x79,0x8d,0xb4,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x007e
#endif

#ifdef LABEL_007f
#define BOARD_CALIBRATION {0x13,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0x88,0x80,0x9d,0x0b,0xc7,0x0d,0xb1,0x80,0xf5,0x06,0x42,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x81,0x8f,0x88,0x8e,0x79,0x8d,0xbf,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x007f
#endif

#ifdef LABEL_0080
#define BOARD_CALIBRATION {0xf0,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xa2,0x81,0x94,0x0b,0xb9,0x0d,0xec,0x81,0xee,0x06,0x37,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xa5,0x8f,0xa5,0x8e,0x97,0x8d,0xca,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0080
#endif

#ifdef LABEL_0081
#define BOARD_CALIBRATION {0xd7,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0x82,0x81,0xa1,0x0b,0xd0,0x0d,0xcd,0x81,0xf6,0x06,0x45,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x96,0x8f,0x9b,0x8e,0x8b,0x8d,0xd4,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0081
#endif

#ifdef LABEL_0082
#define BOARD_CALIBRATION {0x9e,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x04,0x7f,0x89,0x0b,0xc2,0x0d,0x38,0x7f,0xe8,0x06,0x3f,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x7c,0x8f,0x84,0x8e,0x71,0x8d,0xbc,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0082
#endif

#ifdef LABEL_0083
#define BOARD_CALIBRATION {0x3b,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x90,0x80,0xb1,0x0b,0xe3,0x0d,0xeb,0x80,0xfd,0x06,0x50,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x83,0x8f,0x89,0x8e,0x78,0x8d,0xc4,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0083
#endif

#ifdef LABEL_0084
#define BOARD_CALIBRATION {0x05,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0x2d,0x81,0xbd,0x0b,0xe6,0x0d,0x62,0x81,0x07,0x07,0x54,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x96,0x8f,0x9f,0x8e,0x94,0x8d,0xd7,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0084
#endif

#ifdef LABEL_0085
#define BOARD_CALIBRATION {0x4d,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0x51,0x80,0x91,0x0b,0xc2,0x0d,0xb4,0x80,0xea,0x06,0x3e,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x8b,0x8f,0x91,0x8e,0x82,0x8d,0xbf,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0085
#endif

#ifdef LABEL_0086
#define BOARD_CALIBRATION {0x7d,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xa7,0x80,0x87,0x0b,0xb4,0x0d,0xf1,0x80,0xe7,0x06,0x34,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x78,0x8f,0x7a,0x8e,0x65,0x8d,0xa5,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x0086
#endif

#ifdef LABEL_0087
#define BOARD_CALIBRATION {0x0a,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0x2e,0x7e,0x64,0x0b,0x9f,0x0d,0x67,0x7e,0xd1,0x06,0x28,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x91,0x8f,0x96,0x8e,0x84,0x8d,0xca,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0087
#endif

#ifdef LABEL_0088
#define BOARD_CALIBRATION {0x73,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0x49,0x81,0xad,0x0b,0xde,0x0d,0x57,0x81,0x00,0x07,0x51,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x92,0x8f,0x96,0x8e,0x88,0x8d,0xc9,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0088
#endif

#ifdef LABEL_0089
#define BOARD_CALIBRATION {0x4c,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xc9,0x81,0xb1,0x0b,0xdd,0x0d,0xfb,0x81,0x02,0x07,0x50,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9b,0x8f,0x9f,0x8e,0x92,0x8d,0xda,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x0089
#endif

#ifdef LABEL_008a
#define BOARD_CALIBRATION {0x8e,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xd7,0x80,0x88,0x0b,0xb9,0x0d,0xf3,0x80,0xe9,0x06,0x3c,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x95,0x8f,0x9a,0x8e,0x8d,0x8d,0xc7,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22b
#define BOARD_NUMBER       0x008a
#endif

//not accurate calibration values
#ifdef LABEL_008b
#define BOARD_CALIBRATION {0xb1,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xe2,0x7e,0x81,0x0b,0xba,0x0d,0xfc,0x7e,0xe5,0x06,0x3b,0x08,0xfe,0x08,0x14,0x15, \
                           0x92,0x0b,0x03,0x01,0x00,0x02,0x01,0x08,0xa9,0x8f,0xab,0x8e,0x9d,0x8d,0xdf,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x008b
#endif


//not accurate calibration values
#ifdef LABEL_008c
#define BOARD_CALIBRATION {0xb1,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xe2,0x7e,0x81,0x0b,0xba,0x0d,0xfc,0x7e,0xe5,0x06,0x3b,0x08,0xfe,0x08,0x14,0x15, \
                           0x92,0x0b,0x03,0x01,0x00,0x02,0x01,0x08,0xa9,0x8f,0xab,0x8e,0x9d,0x8d,0xdf,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x008c
#endif

//not accurate calibration values
#ifdef LABEL_008d
#define BOARD_CALIBRATION {0xb1,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xe2,0x7e,0x81,0x0b,0xba,0x0d,0xfc,0x7e,0xe5,0x06,0x3b,0x08,0xfe,0x08,0x14,0x15, \
                           0x92,0x0b,0x03,0x01,0x00,0x02,0x01,0x08,0xa9,0x8f,0xab,0x8e,0x9d,0x8d,0xdf,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x008d
#endif

//not accurate calibration values
#ifdef LABEL_008e
#define BOARD_CALIBRATION {0xb1,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xe2,0x7e,0x81,0x0b,0xba,0x0d,0xfc,0x7e,0xe5,0x06,0x3b,0x08,0xfe,0x08,0x14,0x15, \
                           0x92,0x0b,0x03,0x01,0x00,0x02,0x01,0x08,0xa9,0x8f,0xab,0x8e,0x9d,0x8d,0xdf,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x008e
#endif

//not accurate calibration values
#ifdef LABEL_008f
#define BOARD_CALIBRATION {0xb1,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xe2,0x7e,0x81,0x0b,0xba,0x0d,0xfc,0x7e,0xe5,0x06,0x3b,0x08,0xfe,0x08,0x14,0x15, \
                           0x92,0x0b,0x03,0x01,0x00,0x02,0x01,0x08,0xa9,0x8f,0xab,0x8e,0x9d,0x8d,0xdf,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x008f
#endif

//not accurate calibration values
#ifdef LABEL_0090
#define BOARD_CALIBRATION {0xb1,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xe2,0x7e,0x81,0x0b,0xba,0x0d,0xfc,0x7e,0xe5,0x06,0x3b,0x08,0xfe,0x08,0x14,0x15, \
                           0x92,0x0b,0x03,0x01,0x00,0x02,0x01,0x08,0xa9,0x8f,0xab,0x8e,0x9d,0x8d,0xdf,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x0090
#endif

#ifdef LABEL_0091
#define BOARD_CALIBRATION {0x83,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x7a,0x80,0xb3,0x0b,0xdf,0x0d,0x94,0x80,0x04,0x07,0x51,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9f,0x8f,0x9f,0x8e,0x95,0x8d,0xc8,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x0091
#endif

//not accurate calibration values
#ifdef LABEL_0092
#define BOARD_CALIBRATION {0xb1,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xe2,0x7e,0x81,0x0b,0xba,0x0d,0xfc,0x7e,0xe5,0x06,0x3b,0x08,0xfe,0x08,0x14,0x15, \
                           0x92,0x0b,0x03,0x01,0x00,0x02,0x01,0x08,0xa9,0x8f,0xab,0x8e,0x9d,0x8d,0xdf,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x0092
#endif

//not accurate calibration values
#ifdef LABEL_0093
#define BOARD_CALIBRATION {0xb1,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xe2,0x7e,0x81,0x0b,0xba,0x0d,0xfc,0x7e,0xe5,0x06,0x3b,0x08,0xfe,0x08,0x14,0x15, \
                           0x92,0x0b,0x03,0x01,0x00,0x02,0x01,0x08,0xa9,0x8f,0xab,0x8e,0x9d,0x8d,0xdf,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x0093
#endif

#ifdef LABEL_0094
#define BOARD_CALIBRATION {0x8d,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x7b,0x7e,0x7c,0x0b,0xae,0x0d,0xbb,0x7e,0xe0,0x06,0x32,0x08,0xfe,0x08,0x14,0x15, \
                           0x92,0x09,0x02,0x2c,0x00,0x94,0x01,0x08,0x9a,0x8f,0x9e,0x8e,0x94,0x8d,0xd4,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x0094
#endif

#ifdef LABEL_0095
#define BOARD_CALIBRATION {0xb9,0x86,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0x34,0x82,0xdb,0x0b,0x04,0x0e,0x6f,0x82,0x1a,0x07,0x66,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x92,0x8f,0x98,0x8e,0x8e,0x8d,0xcd,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x0095
#endif

#ifdef LABEL_0096
#define BOARD_CALIBRATION {0x45,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x5c,0x7f,0x73,0x0b,0xa2,0x0d,0x8f,0x7f,0xdb,0x06,0x2b,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x88,0x8f,0x8e,0x8e,0x7d,0x8d,0xc5,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x0096
#endif


#ifdef LABEL_0097
#define BOARD_CALIBRATION {0x37,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0x2b,0x81,0xa3,0x0b,0xd2,0x0d,0x1c,0x81,0xfc,0x06,0x4c,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x77,0x8f,0x7d,0x8e,0x6b,0x8d,0xa8,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x0097
#endif

#ifdef LABEL_0098
#define BOARD_CALIBRATION {0xcb,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x48,0x82,0xba,0x0b,0xe0,0x0d,0xa2,0x82,0x04,0x07,0x4f,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x90,0x8f,0x94,0x8e,0x83,0x8d,0xbe,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x0098
#endif

#ifdef LABEL_0099
#define BOARD_CALIBRATION {0x3c,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x93,0x7f,0x7e,0x0b,0x99,0x0d,0xc0,0x7f,0xe3,0x06,0x27,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x91,0x8f,0x98,0x8e,0x84,0x8d,0xce,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x0099
#endif

#ifdef LABEL_009A
#define BOARD_CALIBRATION {0xd9,0x7b,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xea,0x7f,0x81,0x0b,0xb0,0x0d,0x19,0x80,0xe4,0x06,0x33,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x85,0x8f,0x8e,0x8e,0x76,0x8d,0xb8,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x009A
#endif

#ifdef LABEL_009B
#define BOARD_CALIBRATION {0x05,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xd6,0x7e,0x8f,0x0b,0xc0,0x0d,0x0c,0x7f,0xec,0x06,0x3e,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x97,0x8f,0x9a,0x8e,0x8f,0x8d,0xc9,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x009B
#endif

#ifdef LABEL_009C
#define BOARD_CALIBRATION {0x73,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x48,0x80,0xbd,0x0b,0xef,0x0d,0x7f,0x80,0x07,0x07,0x59,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x92,0x8f,0x98,0x8e,0x8b,0x8d,0xc0,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x009C
#endif

#ifdef LABEL_009D
#define BOARD_CALIBRATION {0x18,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x9e,0x7f,0x7d,0x0b,0xad,0x0d,0xd1,0x7f,0xe1,0x06,0x32,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x90,0x8f,0x95,0x8e,0x85,0x8d,0xd3,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x009D
#endif

#ifdef LABEL_009E
#define BOARD_CALIBRATION {0x83,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x7a,0x80,0xb3,0x0b,0xdf,0x0d,0x94,0x80,0x04,0x07,0x51,0x08,0xfe,0x08,0x14,0x15, \
                           0x92,0x09,0x02,0x2c,0x00,0x91,0x01,0x08,0x9f,0x8f,0x9f,0x8e,0x95,0x8d,0xc8,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x009E
#endif

#ifdef LABEL_009F
#define BOARD_CALIBRATION {0x64,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0xce,0x7e,0x74,0x0b,0xa4,0x0d,0xe4,0x7e,0xde,0x06,0x2e,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xab,0x8f,0xb1,0x8e,0xa0,0x8d,0xda,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x009F
#endif

#ifdef LABEL_00A0
#define BOARD_CALIBRATION {0xca,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xfa,0x7e,0x80,0x0b,0x9a,0x0d,0x2e,0x7f,0xe4,0x06,0x29,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x81,0x8f,0x86,0x8e,0x77,0x8d,0xb2,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00A0
#endif

#ifdef LABEL_00A1
#define BOARD_CALIBRATION {0x7c,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x7c,0x80,0x91,0x0b,0xbc,0x0d,0xd0,0x80,0xec,0x06,0x39,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x79,0x8f,0x81,0x8e,0x69,0x8d,0xb6,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00A1
#endif

#ifdef LABEL_00A2
#define BOARD_CALIBRATION {0x62,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xc1,0x80,0xb9,0x0b,0xe7,0x0d,0xe6,0x80,0x06,0x07,0x56,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9c,0x8f,0x9f,0x8e,0x91,0x8d,0xd2,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00A2
#endif

#ifdef LABEL_00A3
#define BOARD_CALIBRATION {0x41,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0x52,0x81,0xae,0x0b,0xca,0x0d,0x80,0x81,0xff,0x06,0x47,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x90,0x8f,0x95,0x8e,0x85,0x8d,0xc5,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00A3
#endif

#ifdef LABEL_00A4
#define BOARD_CALIBRATION {0x4b,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0x54,0x80,0xa3,0x0b,0xbd,0x0d,0x8c,0x80,0xf8,0x06,0x3c,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x94,0x8f,0x9a,0x8e,0x8f,0x8d,0xc2,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00A4
#endif

#ifdef LABEL_00A5
#define BOARD_CALIBRATION {0x15,0x7b,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xfd,0x7f,0x89,0x0b,0xb3,0x0d,0x42,0x80,0xe8,0x06,0x34,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x99,0x8f,0x99,0x8e,0x8a,0x8d,0xcf,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00A5
#endif

#ifdef LABEL_00A6
#define BOARD_CALIBRATION {0Xa6,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xa3,0x80,0xa3,0x0b,0xb6,0x0d,0xe7,0x80,0xf8,0x06,0x3a,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x7d,0x8f,0x87,0x8e,0x75,0x8d,0xb2,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00A6
#endif

#ifdef LABEL_00A7
#define BOARD_CALIBRATION {0X60,0x7b,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xd5,0x7f,0x8b,0x0b,0xaf,0x0d,0x14,0x80,0xe9,0x06,0x35,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xab,0x8f,0xb3,0x8e,0xa8,0x8d,0xde,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00A7
#endif

#ifdef LABEL_00A8
#define BOARD_CALIBRATION {0x7a,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x46,0x81,0x9e,0x0b,0xd0,0x0d,0x9a,0x81,0xf4,0x06,0x45,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x96,0x8f,0x9e,0x8e,0x8a,0x8d,0xd0,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00A8
#endif

#ifdef LABEL_00A9
#define BOARD_CALIBRATION {0x64,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xa6,0x80,0xc3,0x0b,0xf1,0x0d,0xd1,0x80,0x0c,0x07,0x5b,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9e,0x8f,0xa2,0x8e,0x8f,0x8d,0xca,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00A9
#endif

#ifdef LABEL_00AA
#define BOARD_CALIBRATION {0x88,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xe0,0x7f,0x85,0x0b,0xac,0x0d,0xe4,0x7f,0xe9,0x06,0x35,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xaa,0x8f,0xaf,0x8e,0xa2,0x8d,0xd9,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00AA
#endif

#ifdef LABEL_00AB
#define BOARD_CALIBRATION {0x66,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x1a,0x80,0x99,0x0b,0xaa,0x0d,0x53,0x80,0xf2,0x06,0x33,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x6c,0x8f,0x75,0x8e,0x68,0x8d,0xa7,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00AB
#endif

#ifdef LABEL_00AC
#define BOARD_CALIBRATION {0xdc,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0x5e,0x80,0xec,0x0b,0xd3,0x0d,0x8a,0x80,0x03,0x07,0x4c,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x97,0x8f,0xa1,0x8e,0x94,0x8d,0xd6,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00AC
#endif

#ifdef LABEL_00AD
#define BOARD_CALIBRATION {0xf9,0x7b,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xe2,0x7f,0x6c,0x0b,0x98,0x0d,0x36,0x80,0xd5,0x06,0x24,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x8b,0x8f,0x93,0x8e,0x83,0x8d,0xba,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00AD
#endif

#ifdef LABEL_00AE
#define BOARD_CALIBRATION {0xc3,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0x48,0x80,0xa6,0x0b,0xbd,0x0d,0x79,0x80,0xfa,0x06,0x3c,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x8c,0x8f,0x95,0x8e,0x83,0x8d,0xbf,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00AE
#endif

#ifdef LABEL_00AF
#define BOARD_CALIBRATION {0xc4,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0x7b,0x82,0xce,0x0b,0xe5,0x0d,0x96,0x82,0x13,0x07,0x55,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xa5,0x8f,0xad,0x8e,0x9d,0x8d,0xdd,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00AF
#endif

#ifdef LABEL_00B0
#define BOARD_CALIBRATION {0xe3,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x01,0x7f,0x55,0x0b,0x79,0x0d,0x5e,0x7f,0xc7,0x06,0x10,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x91,0x8f,0x94,0x8e,0x85,0x8d,0xce,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00B0
#endif

#ifdef LABEL_00B1
#define BOARD_CALIBRATION {0x3e,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0x33,0x7e,0x7e,0x0b,0xb8,0x0d,0x5b,0x7e,0xe2,0x06,0x39,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x92,0x8f,0x97,0x8e,0x8d,0x8d,0xc9,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00B1
#endif

#ifdef LABEL_00B2
#define BOARD_CALIBRATION {0x6b,0x87,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xd0,0x81,0xa5,0x0b,0xba,0x0d,0x22,0x82,0xf8,0x06,0x39,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x95,0x8f,0x9a,0x8e,0x87,0x8d,0xc5,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00B2
#endif

#ifdef LABEL_00B3
#define BOARD_CALIBRATION {0x7f,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xa8,0x81,0xcb,0x0b,0xef,0x0d,0xf0,0x81,0x10,0x07,0x58,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xa1,0x8f,0xa4,0x8e,0x9b,0x8d,0xdc,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00B3
#endif

#ifdef LABEL_00B4
#define BOARD_CALIBRATION {0x54,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0x7d,0x80,0x98,0x0b,0xc2,0x0d,0xcb,0x80,0xf0,0x06,0x3e,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9e,0x8f,0xa4,0x8e,0x94,0x8d,0xd6,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00B4
#endif

#ifdef LABEL_00B5
#define BOARD_CALIBRATION {0xe3,0x7a,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xf9,0x7f,0x9a,0x0b,0xca,0x0d,0x3c,0x80,0xf3,0x06,0x43,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xaa,0x8f,0xaf,0x8e,0xa4,0x8d,0x6e,0x87}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00B5
#endif

#ifdef LABEL_00B6
#define BOARD_CALIBRATION {0xe5,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xe9,0x7f,0xbf,0x0b,0xdf,0x0d,0xf4,0x7f,0x0b,0x07,0x55,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x80,0x8f,0x89,0x8e,0x74,0x8d,0xb2,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00B6
#endif

#ifdef LABEL_00B7
#define BOARD_CALIBRATION {0x4c,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0xd3,0x81,0xa8,0x0b,0xcb,0x0d,0xf2,0x81,0xfd,0x06,0x45,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x83,0x8f,0x8b,0x8e,0x7d,0x8d,0xcd,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00B7
#endif

#ifdef LABEL_00B8
#define BOARD_CALIBRATION {0xf8,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x18,0x80,0xac,0x0b,0xdb,0x0d,0x68,0x80,0xfb,0x06,0x4c,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x95,0x8f,0x9c,0x8e,0x88,0x8d,0xce,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00B8
#endif

#ifdef LABEL_00B9
#define BOARD_CALIBRATION {0x34,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x4f,0x82,0xc0,0x0b,0xe7,0x0d,0xcf,0x82,0x06,0x07,0x50,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xb5,0x8f,0xbb,0x8e,0xad,0x8d,0x69,0x87}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00B9
#endif

#ifdef LABEL_00BA
#define BOARD_CALIBRATION {0x49,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xd0,0x80,0xbe,0x0b,0xf0,0x0d,0xf7,0x80,0x08,0x07,0x5b,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9f,0x8f,0xa7,0x8e,0x95,0x8d,0xd7,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00BA
#endif

#ifdef LABEL_00BB
#define BOARD_CALIBRATION {0x4a,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0x68,0x7f,0xa8,0x0b,0xc7,0x0d,0x80,0x7f,0xfe,0x06,0x46,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x99,0x8f,0xa1,0x8e,0x8d,0x8d,0xc8,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00BB
#endif

#ifdef LABEL_00BC
#define BOARD_CALIBRATION {0x54,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xd6,0x80,0xaa,0x0b,0xcb,0x0d,0x17,0x81,0xfc,0x06,0x46,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x92,0x8f,0x93,0x8e,0x85,0x8d,0xc5,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00BC
#endif

#ifdef LABEL_00BD
#define BOARD_CALIBRATION {0x23,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x43,0x81,0xa6,0x0b,0xbe,0x0d,0x70,0x81,0xfb,0x06,0x3c,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x79,0x8f,0x7e,0x8e,0x6e,0x8d,0xaf,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00BD
#endif

#ifdef LABEL_00BE
#define BOARD_CALIBRATION {0x48,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0x9d,0x81,0xde,0x0b,0xb4,0x0d,0xba,0x81,0xfb,0x06,0x3b,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x81,0x8f,0x88,0x8e,0x7b,0x8d,0xb3,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00BE
#endif

#ifdef LABEL_00BF
#define BOARD_CALIBRATION {0x2f,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0xf3,0x80,0xa0,0x0b,0xcc,0x0d,0x46,0x81,0xf5,0x06,0x43,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x96,0x8f,0x9b,0x8e,0x8a,0x8d,0xcf,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00BF
#endif

#ifdef LABEL_00C0
#define BOARD_CALIBRATION {0xf1,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xf4,0x7e,0x62,0x0b,0x99,0x0d,0x58,0x7f,0xce,0x06,0x22,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x93,0x8f,0x96,0x8e,0x8b,0x8d,0xcd,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00C0
#endif

#ifdef LABEL_00C1
#define BOARD_CALIBRATION {0xbb,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x90,0x80,0x8c,0x0b,0xba,0x0d,0xe6,0x80,0xe9,0x06,0x38,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x8f,0x8f,0x94,0x8e,0x83,0x8d,0xbb,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00C1
#endif

#ifdef LABEL_00C2
#define BOARD_CALIBRATION {0x82,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0x15,0x81,0xbf,0x0b,0xe8,0x0d,0x57,0x81,0x08,0x07,0x55,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x83,0x8f,0x86,0x8e,0x74,0x8d,0xb1,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00C2
#endif

#ifdef LABEL_00C3
#define BOARD_CALIBRATION {0x88,0x86,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0x0e,0x83,0xde,0x0b,0x03,0x0e,0x67,0x83,0x1a,0x07,0x64,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9a,0x8f,0x9f,0x8e,0x8f,0x8d,0xce,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00C3
#endif

#ifdef LABEL_00C4
#define BOARD_CALIBRATION {0x87,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0xc6,0x80,0xa2,0x0b,0xd1,0x0d,0xd7,0x80,0xf9,0x06,0x4a,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x99,0x8f,0x9d,0x8e,0x8b,0x8d,0xd1,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00C4
#endif

#ifdef LABEL_00C5
#define BOARD_CALIBRATION {0x18,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x2d,0x7f,0x83,0x0b,0xbe,0x0d,0x97,0x7f,0xe2,0x06,0x38,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x96,0x8f,0x9b,0x8e,0x8b,0x8d,0xc4,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00C5
#endif

#ifdef LABEL_00C6
#define BOARD_CALIBRATION {0x78,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0x81,0x7f,0x98,0x0b,0xd7,0x0d,0xca,0x7f,0xf1,0x06,0x49,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x86,0x8f,0x8a,0x8e,0x79,0x8d,0xb5,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00C6
#endif

#ifdef LABEL_00C7
#define BOARD_CALIBRATION {0x73,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x48,0x80,0xbd,0x0b,0xef,0x0d,0x7f,0x80,0x07,0x07,0x59,0x08,0xfe,0x08,0x14,0x15, \
                           0x92,0x09,0x02,0x2c,0x00,0x9c,0x01,0x08,0x92,0x8f,0x98,0x8e,0x8b,0x8d,0xc0,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00C7
#endif

#ifdef LABEL_00C8
#define BOARD_CALIBRATION {0x5e,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0x70,0x81,0xa7,0x0b,0xd7,0x0d,0xa2,0x81,0xfb,0x06,0x4b,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x96,0x8f,0x99,0x8e,0x8a,0x8d,0xc3,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00C8
#endif

#ifdef LABEL_00C9
#define BOARD_CALIBRATION {0x53,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xe8,0x81,0xe3,0x0b,0x16,0x0e,0x62,0x82,0x1b,0x07,0x6c,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x8c,0x8f,0x94,0x8e,0x84,0x8d,0xce,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00C9
#endif

#ifdef LABEL_00CA
#define BOARD_CALIBRATION {0x05,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x53,0x82,0xc7,0x0b,0xef,0x0d,0x76,0x82,0x0f,0x07,0x5b,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x8e,0x8f,0x92,0x8e,0x82,0x8d,0xcb,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00CA
#endif

#ifdef LABEL_00CB
#define BOARD_CALIBRATION {0xdf,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x2f,0x81,0x8e,0x0b,0xbd,0x0d,0x69,0x81,0xeb,0x06,0x3b,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9d,0x8f,0xa2,0x8e,0x94,0x8d,0xd8,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00CB
#endif

#ifdef LABEL_00CC
#define BOARD_CALIBRATION {0x5b,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x41,0x81,0xad,0x0b,0xdf,0x0d,0x97,0x81,0xfc,0x06,0x4e,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x91,0x8f,0x96,0x8e,0x85,0x8d,0xc6,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00CC
#endif

#ifdef LABEL_00CD
#define BOARD_CALIBRATION {0x8f,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x55,0x80,0xc9,0x0b,0xfd,0x0d,0xad,0x80,0x0d,0x07,0x60,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x8c,0x8f,0x94,0x8e,0x81,0x8d,0xbe,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00CD
#endif

#ifdef LABEL_00CE
#define BOARD_CALIBRATION {0xf1,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x5f,0x81,0xa4,0x0b,0xcd,0x0d,0xa3,0x81,0xf8,0x06,0x45,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x73,0x8f,0x77,0x8e,0x66,0x8d,0xb2,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00CE
#endif

#ifdef LABEL_00CF
#define BOARD_CALIBRATION {0x56,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x14,0x83,0xd6,0x0b,0xfb,0x0d,0x41,0x83,0x17,0x07,0x61,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x99,0x8f,0x9c,0x8e,0x8f,0x8d,0xd9,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00CF
#endif

#ifdef LABEL_00D0
#define BOARD_CALIBRATION {0x2c,0x86,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xe0,0x81,0xd1,0x0b,0xfa,0x0d,0x64,0x82,0x10,0x07,0x5c,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x7b,0x8f,0x7e,0x8e,0x6b,0x8d,0xae,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00D0
#endif

#ifdef LABEL_00D1
#define BOARD_CALIBRATION {0x3a,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xa7,0x81,0x84,0x0b,0xac,0x0d,0xd8,0x81,0xe6,0x06,0x32,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x83,0x8f,0x8f,0x8e,0x7c,0x8d,0xc2,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00D1
#endif

#ifdef LABEL_00D2
#define BOARD_CALIBRATION {0x9a,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x87,0x7f,0x90,0x0b,0xbd,0x0d,0xb4,0x7f,0xed,0x06,0x3c,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x90,0x8f,0x95,0x8e,0x8b,0x8d,0xd0,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00D2
#endif

#ifdef LABEL_00D3
#define BOARD_CALIBRATION {0xe5,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x20,0x81,0x98,0x0b,0xc3,0x0d,0x6e,0x81,0xf0,0x06,0x3d,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x7e,0x8f,0x86,0x8e,0x77,0x8d,0xbb,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00D3
#endif

#ifdef LABEL_00D4
#define BOARD_CALIBRATION {0x7f,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x67,0x80,0x90,0x0b,0xbf,0x0d,0x91,0x80,0xed,0x06,0x3e,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9c,0x8f,0xa2,0x8e,0x91,0x8d,0xd3,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00D4
#endif

#ifdef LABEL_00D5
#define BOARD_CALIBRATION {0x96,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x1a,0x81,0xa7,0x0b,0xcf,0x0d,0x6f,0x81,0xf9,0x06,0x45,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x93,0x8f,0x95,0x8e,0x81,0x8d,0xbb,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00D5
#endif

#ifdef LABEL_00D6
#define BOARD_CALIBRATION {0x77,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xc2,0x7e,0x95,0x0b,0xd1,0x0d,0x01,0x7f,0xef,0x06,0x46,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xa2,0x8f,0xa7,0x8e,0x9a,0x8d,0xcf,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00D6
#endif

#ifdef LABEL_00D7
#define BOARD_CALIBRATION {0x8d,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xa0,0x7f,0x69,0x0b,0x9a,0x0d,0xe2,0x7f,0xd4,0x06,0x26,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x89,0x8f,0x8e,0x8e,0x78,0x8d,0xb8,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00D7
#endif

#ifdef LABEL_00D8
#define BOARD_CALIBRATION {0x29,0x86,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x4d,0x81,0xdc,0x0b,0x05,0x0e,0x77,0x81,0x1b,0x07,0x67,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x80,0x8f,0x8a,0x8e,0x75,0x8d,0xc0,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00D8
#endif

#ifdef LABEL_00D9
#define BOARD_CALIBRATION {0x66,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xd0,0x81,0xc0,0x0b,0xe9,0x0d,0xfb,0x81,0x0a,0x07,0x57,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x7a,0x8f,0x83,0x8e,0x70,0x8d,0xbb,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00D9
#endif

#ifdef LABEL_00DA
#define BOARD_CALIBRATION {0xe2,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x10,0x7f,0x8f,0x0b,0xcf,0x0d,0x5a,0x7f,0xeb,0x06,0x45,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x95,0x8f,0x9b,0x8e,0x8e,0x8d,0xcd,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00DA
#endif

#ifdef LABEL_00DB
#define BOARD_CALIBRATION {0xf4,0x7b,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xe9,0x7f,0x80,0x0b,0xb8,0x0d,0x4a,0x80,0xe1,0x06,0x36,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x88,0x8f,0x89,0x8e,0x77,0x8d,0xc1,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00DB
#endif

#ifdef LABEL_00DC
#define BOARD_CALIBRATION {0x6d,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00, \
                           0xd7,0x80,0xcc,0x0b,0xfa,0x0d,0x25,0x81,0x0e,0x07,0x5e,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xa7,0x8f,0xab,0x8e,0x9c,0x8d,0x61,0x87}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00DC
#endif

#ifdef LABEL_00DD
#define BOARD_CALIBRATION {0xe7,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x34,0x81,0xb5,0x0b,0xe0,0x0d,0x9f,0x81,0x00,0x07,0x4d,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x8e,0x8f,0x95,0x8e,0x85,0x8d,0xc3,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00DD
#endif

#ifdef LABEL_00DE
#define BOARD_CALIBRATION {0x79,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xe2,0x80,0xc3,0x0b,0xdc,0x0d,0x14,0x81,0x0c,0x07,0x4f,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x80,0x8f,0x86,0x8e,0x74,0x8d,0xab,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00DE
#endif

#ifdef LABEL_00DF
#define BOARD_CALIBRATION {0x94,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xb1,0x80,0x72,0x0b,0x89,0x0d,0xe4,0x80,0xdb,0x06,0x1d,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x75,0x8f,0x78,0x8e,0x65,0x8d,0x98,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x00DF
#endif

#ifdef LABEL_00E0
#define BOARD_CALIBRATION {0xc5,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xa9,0x81,0xa2,0x0b,0xbd,0x0d,0xfc,0x81,0xf6,0x06,0x3b,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x97,0x8f,0x9f,0x8e,0x91,0x8d,0xd2,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x00E0
#endif

#ifdef LABEL_00E1
#define BOARD_CALIBRATION {0x12,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x32,0x7f,0x75,0x0b,0x9a,0x0d,0x4d,0x7f,0xde,0x06,0x2a,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9d,0x8f,0xa2,0x8e,0x95,0x8d,0xd7,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x00E1
#endif

#ifdef LABEL_00E2
#define BOARD_CALIBRATION {0x70,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x65,0x7f,0x8a,0x0b,0xb8,0x0d,0xa2,0x7f,0xe8,0x06,0x38,0x08,0xfe,0x08,0xff,0xff, \
                             0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x94,0x8f,0x9a,0x8e,0x8b,0x8d,0xc7,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x00E2
#endif

#ifdef LABEL_00E3
#define BOARD_CALIBRATION {0x98,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x6e,0x80,0x9c,0x0b,0xc7,0x0d,0x7e,0x80,0xf6,0x06,0x44,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9c,0x8f,0xa6,0x8e,0x96,0x8d,0xca,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x00E3
#endif

#ifdef LABEL_00E4
#define BOARD_CALIBRATION {0x47,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xe4,0x80,0xaa,0x0b,0xc5,0x0d,0x3d,0x81,0xfa,0x06,0x41,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x96,0x8f,0x99,0x8e,0x8a,0x8d,0xc6,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x00E4
#endif

#ifdef LABEL_00E5
#define BOARD_CALIBRATION {0x71,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x05,0x80,0xbf,0x0b,0xe1,0x0d,0x2a,0x80,0x09,0x07,0x52,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x92,0x8f,0x99,0x8e,0x88,0x8d,0xd1,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x00E5
#endif

#ifdef LABEL_00E6
#define BOARD_CALIBRATION {0x19,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00, \
                           0xd7,0x80,0xd2,0x0b,0xb5,0x0d,0x02,0x81,0xf4,0x06,0x3a,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x99,0x8f,0xa0,0x8e,0x92,0x8d,0xc4,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x00E6
#endif

#ifdef LABEL_00E7
#define BOARD_CALIBRATION {0x89,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xec,0x7e,0x8c,0x0b,0xb0,0x0d,0xfc,0x7e,0xed,0x06,0x38,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9f,0x8f,0xa5,0x8e,0x97,0x8d,0xd4,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x00E7
#endif

#ifdef LABEL_00E8
#define BOARD_CALIBRATION {0x4a,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xdd,0x80,0xab,0x0b,0xc3,0x0d,0xf5,0x80,0xfe,0x06,0x44,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x8a,0x8f,0x8f,0x8e,0x7f,0x8d,0xc1,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x00E8
#endif

#ifdef LABEL_00E9
#define BOARD_CALIBRATION {0x3a,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x19,0x7f,0x68,0x0b,0x97,0x0d,0x58,0x7f,0xd4,0x06,0x24,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xae,0x8f,0xaf,0x8e,0xa0,0x8d,0xde,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x00E9
#endif

#ifdef LABEL_00EA
#define BOARD_CALIBRATION {0x1b,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xb7,0x7e,0x7e,0x0b,0xb0,0x0d,0xf4,0x7e,0xe1,0x06,0x33,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xa8,0x8f,0xae,0x8e,0x9e,0x8d,0xd5,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x00EA
#endif

#ifdef LABEL_00EB
#define BOARD_CALIBRATION {0x6f,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x88,0x81,0xd3,0x0b,0xf3,0x0d,0xdd,0x81,0x13,0x07,0x5b,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x87,0x8f,0x8d,0x8e,0x83,0x8d,0xd2,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x00EB
#endif

#ifdef LABEL_00EC
#define BOARD_CALIBRATION {0x5b,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0x8d,0x82,0xd7,0x0b,0xfd,0x0d,0xe6,0x82,0x16,0x07,0x60,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x9c,0x8f,0xa1,0x8e,0x91,0x8d,0xc9,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x00EC
#endif

#ifdef LABEL_00ED
#define BOARD_CALIBRATION {0xdd,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xd4,0x80,0x8f,0x0b,0xbc,0x0d,0x26,0x81,0xeb,0x06,0x3a,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xb3,0x8f,0xb5,0x8e,0xa8,0x8d,0x6a,0x87}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x00ED
#endif

#ifdef LABEL_00EE
#define BOARD_CALIBRATION {0xcb,0x86,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xe2,0x7d,0x4d,0x0b,0x73,0x0d,0x12,0x7e,0xc5,0x06,0x0f,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0xb2,0x8f,0xb5,0x8e,0xaa,0x8d,0x6b,0x87}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x00EE
#endif

#ifdef LABEL_00F0
#define BOARD_CALIBRATION {0x41,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00, \
                           0xb2,0x80,0x95,0x0b,0xc8,0x0d,0x38,0x81,0xec,0x06,0x3d,0x08,0xfe,0x08,0xff,0xff, \
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x94,0x8f,0x99,0x8e,0x87,0x8d,0xc4,0x86}
#define BOARD_TYPE         BOARD_TYPE_GINA
#define BOARD_VERSION      BOARD_VERSION_22c
#define BOARD_NUMBER       0x00F0
#endif

#ifdef LABEL_00F1
#define BOARD_CALIBRATION {0x57,0x86,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00,\
                           0xaf,0x81,0xb5,0x0b,0xca,0x0d,0x01,0x82,0x02,0x07,0x42,0x08,0xfe,0x08,0xff,0xff,\
                           0xff,0xff,0xff,0xff,0xff,0xff,0x01,0x08,0x7a,0x8f,0x7d,0x8e,0x68,0x8d,0xa0,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x00F1
#endif


#ifdef LABEL_00F2
#define BOARD_CALIBRATION {0x8e,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x02,0x00,0x0b,0x80,\
                           0x94,0x0b,0xac,0x0d,0x2f,0x80,0xf0,0x06,0x33,0x08,0xfe,0x08,0xff,0xff,0xff,0xff,0xff,\
                           0xff,0xff,0xff,0x01,0x08,0x91,0x8f,0x94,0x8e,0x88,0x8d,0xd4,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x00F2
#endif


#ifdef LABEL_00F3
#define BOARD_CALIBRATION {0x79,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00,0xd6,0x7f,0xb3,0x0b,\
                           0xe1,0x0d,0xe9,0x7f,0x03,0x07,0x53,0x08,0xfe,0x08,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\
                           0x01,0x08,0xa3,0x8f,0xad,0x8e,0x9e,0x8d,0xdd,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x00F3
#endif

#ifdef LABEL_00F4
#define BOARD_CALIBRATION {0x6d,0x85,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x01,0x00,0x9e,0x80,0xb3,0x0b,\
                           0xd2,0x0d,0xad,0x80,0x04,0x07,0x4a,0x08,0xfe,0x08,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\
                           0x01,0x08,0xa8,0x8f,0xae,0x8e,0xa3,0x8d,0xdd,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x00F4
#endif

#ifdef LABEL_00F5
#define BOARD_CALIBRATION {0x93,0x84,0xfe,0x16,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\
                           0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x08,0x10,0x00,0x80,0x00,0x00,0x4b,0x7f,0x8a,0x0b,\
                           0xb3,0x0d,0x75,0x7f,0xea,0x06,0x39,0x08,0xfe,0x08,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,\
                           0x01,0x08,0xa1,0x8f,0xa7,0x8e,0x95,0x8d,0xdc,0x86}
#define BOARD_TYPE         BOARD_TYPE_BASETATION
#define BOARD_VERSION      BOARD_VERSION_MSP1
#define BOARD_NUMBER       0x00F5
#endif

#endif
